import { readdirSync } from "fs";
import { join } from "path";
import { spawn } from "child_process";

const iconPath = join(process.cwd(), "src", "assets", "icons");

const getFileList = (path: string): string[] => {
  const fileList = readdirSync(path);

  return fileList.reduce((arr, file) => {
    const ext = file.split(".")[1];

    if (ext === "svg") {
      arr.push([path, file].join("/"));
    }

    if (!ext) {
      arr.push(...getFileList([path, file].join("/")));
    }

    return arr;
  }, []);
};
const main = async (): Promise<void> => {
  const fileList = getFileList(iconPath);

  const iconNameEnum =
    fileList.reduce((iconEnum, str) => {
      const withoutBase = str.replace(iconPath, "").slice(1);

      const fileName = withoutBase.slice(0, -4);
      const key = fileName
        .split("/")
        .filter(Boolean)
        .join("_")
        .replace(/[\s-]/g, "_")
        .replace("small", "sm")
        .replace("medium", "md")
        .replace("large", "lg")
        .toUpperCase();

      return iconEnum + `\n   ${key} = "${fileName}",`;
    }, `export enum IconName {`) + "\n}";

  const proc = spawn("pbcopy");
  proc.stdin.write(iconNameEnum);
  proc.stdin.end();

  console.log("✔️ Successfully copied enum to clipboard");
};

main();
