import { describe, expect, it } from "vitest";
import { mount } from "@vue/test-utils";
import { CTActionBar } from "../action-bar";
import { cleanHTML } from "../../utilities/vitest";
import { IconName } from "../icon";

const slots = {
  extended: `Extended slot`,
  extendedBgIn: `Extended bg in slot`,
  extendedBgOut: `Extended bg out slot`,
  start: `Start slot`,
  center: `Center`,
  end: `End slot`,
};

const { label, icon } = { label: "Label", icon: IconName.MD_CONTENT_SUBMENU };

const { start, center, end, extended } = slots;

describe("ActionBar", () => {
  it("renders start slot", () => {
    const wrapper = mount(CTActionBar, { slots: { start } });

    expect(cleanHTML(wrapper.find({ ref: "startSlot" }).text())).toBe(start);
  });

  it("renders center slot", () => {
    const wrapper = mount(CTActionBar, { slots: { center } });

    expect(cleanHTML(wrapper.find({ ref: "centerSlot" }).text())).toBe(center);
  });

  it("renders end slot", () => {
    const wrapper = mount(CTActionBar, { slots: { end } });

    expect(cleanHTML(wrapper.find({ ref: "endSlot" }).text())).toBe(end);
  });

  it("renders extended slot", async () => {
    const wrapper = mount(CTActionBar, { slots: { extended } });
    expect(wrapper.find({ ref: "extendedSlotRef" }).exists()).toBe(true);

    expect(wrapper.find({ ref: "labelContainerRef" }).exists()).toStrictEqual(
      false,
    );

    await wrapper.setProps({ label });

    expect(wrapper.findComponent({ ref: "iconRef" }).exists()).toStrictEqual(
      false,
    );

    expect(wrapper.find({ ref: "labelContainerRef" }).exists()).toStrictEqual(
      true,
    );

    expect(wrapper.find({ ref: "labelRef" }).text()).toStrictEqual(label);

    await wrapper.setProps({ icon });

    expect(
      wrapper.findComponent({ ref: "iconRef" }).props("name"),
    ).toStrictEqual(icon);
  });
});
