import { describe, it, expect, vi } from "vitest";
import { CTStatusBar, StatusBarStatus } from "../action-bar";
import { mount } from "@vue/test-utils";

describe("StatusBar", () => {
  it(`should render status ${StatusBarStatus.UNSAVED}`, async () => {
    const wrapper = mount(CTStatusBar, {
      props: { status: StatusBarStatus.UNSAVED },
    });

    expect(wrapper.findComponent({ ref: "discardRef" }).exists()).toBe(true);
    await wrapper.findComponent({ ref: "discardRef" }).trigger("click");
    expect(wrapper.emitted("discard")).toBeTruthy();

    expect(wrapper.findComponent({ ref: "saveRef" }).exists()).toBe(true);
    await wrapper.findComponent({ ref: "saveRef" }).trigger("click");
    expect(wrapper.emitted("save")).toBeTruthy();
  });

  it(`should render status ${StatusBarStatus.SAVING}`, async () => {
    const wrapper = mount(CTStatusBar, {
      props: { status: StatusBarStatus.SAVING },
    });

    expect(wrapper.findComponent({ ref: "cancelRef" }).exists()).toBe(true);
    await wrapper.findComponent({ ref: "cancelRef" }).trigger("click");
    expect(wrapper.emitted("cancel")).toBeTruthy();
  });

  it(`should render status ${StatusBarStatus.SAVING_ERROR}`, async () => {
    const errorMessage = "test";
    const wrapper = mount(CTStatusBar, {
      props: {
        status: StatusBarStatus.SAVING_ERROR,
        errorMessage,
      },
    });

    expect(wrapper.find({ ref: "errorMessageRef" }).text()).toBe(errorMessage);

    expect(wrapper.findComponent({ ref: "closeRef" }).exists()).toBe(true);
    await wrapper.findComponent({ ref: "closeRef" }).trigger("click");
    expect(wrapper.emitted("close")).toBeTruthy();
  });

  it(`should render status ${StatusBarStatus.SAVING_SUCCESS}`, async () => {
    vi.useFakeTimers();
    const wrapper = mount(CTStatusBar, {
      props: {
        status: StatusBarStatus.SAVING_SUCCESS,
      },
    });

    vi.runOnlyPendingTimers();
    expect(wrapper.emitted("close")).toBeTruthy();
  });
});
