import {
  CTActionBar,
  CTStatusBar,
  ExtendedType,
  StatusBarStatus,
} from "../action-bar";
import type { ActionBarProps, StatusBarProps } from "./types";
import { IconName } from "../icon";
import { CTButton } from "../button";
import { ButtonType } from "../base-button";
import { actionBarStub, statusBarStub } from "./stub";
import { ref } from "vue";
import type { Meta, StoryObj } from "@storybook/vue3";
import { iconArgTypes } from "../../utilities/storybook";

const meta: Meta<typeof CTActionBar> = {
  title: "Actionbar",
  component: CTActionBar,
  argTypes: {
    label: { control: "text" },
    type: {
      control: "select",
      options: Object.values(ExtendedType),
    },
    ...iconArgTypes,
  },
};

export const Developers: StoryObj<typeof CTActionBar> = {
  args: {
    ...actionBarStub,
  },
  render: (args: ActionBarProps) => ({
    components: { CTActionBar, CTButton },
    setup() {
      const isExtended = ref(false);
      return {
        isExtended,
        ButtonType,
        IconName,
        args,
      };
    },
    template: `
      <div class="h-[500vh]">
      <CTActionBar v-bind="args" class="sticky top-16">
        <template v-slot:start>
          <div class="flex gap-x-2">
            <CTButton is-rounded :type="ButtonType.PRIMARY" @click="isExtended = !isExtended">Toggle extended: {{isExtended}}</CTButton>
          </div>
        </template>
        <template v-slot:end>
          <div class="flex gap-x-2">
            <CTButton :icon-left="IconName.CHEVRON_LEFT" :type="ButtonType.SECONDARY" is-rounded>
              Introduction
            </CTButton>
            <CTButton :icon-right="IconName.CHEVRON_RIGHT" :type="ButtonType.SECONDARY" is-rounded>
              Introduction
            </CTButton>
          </div>
        </template>

        <template #extended v-if="isExtended">
          <div class="flex gap-x-2">
            <CTButton :icon-left="IconName.CHEVRON_LEFT" :type="ButtonType.WARNING" is-rounded>
              Introduction
            </CTButton>
            <CTButton :icon-right="IconName.CHEVRON_RIGHT" :type="ButtonType.WARNING" is-rounded>
              Introduction
            </CTButton>
          </div>
        </template>
      </CTActionBar>
      </div>
    `,
  }),
};

export const StatusBar: StoryObj<typeof CTStatusBar> = {
  argTypes: {
    status: { control: "select", options: Object.values(StatusBarStatus) },
    isRounded: { control: "boolean" },
  },
  args: {
    ...statusBarStub,
  },
  render: (args: StatusBarProps) => ({
    components: { CTStatusBar, CTButton },
    setup() {
      const status = ref(StatusBarStatus.SAVING_ERROR);
      const showStatusBar = ref(false);

      const onSave = (): void => {
        status.value = StatusBarStatus.SAVING_SUCCESS;
      };
      return {
        StatusBarStatus,
        showStatusBar,
        onSave,
        status,
        args,
      };
    },
    template: `<div class="h-[500vh] flex flex-col gap-4 items-start">
      <CTButton @click="showStatusBar = !showStatusBar">Toggle</CTButton>
      <CTStatusBar class="w-full" v-if="showStatusBar" v-bind="args" :status="status" @save="onSave"/>
  </div>`,
  }),
};

export default meta;
