import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import { BannerColor, CTWarningBanner } from "./index";
import { warningBannerStub } from "./stub";
import { CTTag, TagType } from "../tag";
import { CTIcon } from "../icon";
import { CTContent } from "../content";

const { label, tag, icon, orientation } = warningBannerStub;

describe("Warning banner", () => {
  it("renders label", () => {
    const wrapper = mount(CTWarningBanner, { props: { label } });

    expect(wrapper.findComponent(CTContent).exists()).toBe(true);
  });

  it("renders tag", async () => {
    const wrapper = mount(CTWarningBanner, { props: { label } });

    expect(wrapper.findComponent(CTTag).exists()).toBe(false);

    await wrapper.setProps({ tag });

    expect(wrapper.findComponent(CTTag).exists()).toBe(true);
    expect(
      wrapper.findComponent(CTTag).classes(`type-${TagType.WARNING}`),
    ).toBe(true);
    await wrapper.setProps({ color: BannerColor.NOTE });
    expect(wrapper.findComponent(CTTag).classes(`type-${TagType.NOTE}`)).toBe(
      true,
    );

    await wrapper.setProps({ color: BannerColor.BODY });
    expect(wrapper.findComponent(CTTag).classes(`type-${TagType.BASE}`)).toBe(
      true,
    );
  });

  it("renders icon", async () => {
    const wrapper = mount(CTWarningBanner, { props: { label } });

    expect(wrapper.findComponent(CTIcon).exists()).toBe(false);

    await wrapper.setProps({ icon });

    expect(wrapper.findComponent(CTIcon).exists()).toBe(true);
  });

  it("has orientation class", async () => {
    const wrapper = mount(CTWarningBanner, { props: { label } });

    expect(wrapper.classes("orientation-vertical")).toBe(true);

    await wrapper.setProps({ orientation });

    expect(wrapper.classes(`orientation-${orientation}`)).toBe(true);
  });
});
