import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import CTButton from "./Button.vue";
import { CTIcon, IconName } from "../icon";
import { stub as props } from "./stub";
import { CTBaseButton } from "../base-button";

const { label, type, variant, size } = props;

describe("Button", () => {
  it("renders label", async () => {
    const wrapper = mount(CTButton, { props: { type } });
    expect(wrapper.find({ ref: "labelRef" }).exists()).toBe(false);

    await wrapper.setProps({ label });
    expect(wrapper.find({ ref: "labelRef" }).text()).toBe(label);
  });

  it("emits click", async () => {
    const wrapper = mount(CTButton, {
      props: { ...props, isDisabled: undefined },
    });

    await wrapper.trigger("click");

    expect(wrapper.emitted("click")?.length).toBe(1);

    await wrapper.trigger("click");

    expect(wrapper.emitted("click")?.length).toBe(2);

    await wrapper.trigger("click");
    await wrapper.trigger("click");

    expect(wrapper.emitted("click")?.length).toBe(4);
  });

  it("renders slot", async () => {
    const wrapper = mount(CTButton, {
      props: { type },
      slots: { default: label! },
    });

    expect(wrapper.text()).toBe(label);
  });

  it("renders icon left", async () => {
    const wrapper = mount(CTButton, {
      props: { ...props, iconLeft: undefined, iconRight: undefined },
    });
    expect(wrapper.findComponent(CTIcon).exists()).toBe(false);

    await wrapper.setProps({ iconLeft: IconName.MD_NAVIGATION_ARROW_LEFT });
    expect(wrapper.findComponent(CTIcon).exists()).toBe(true);
  });

  it("renders icon right", async () => {
    const wrapper = mount(CTButton, {
      props: { ...props, iconLeft: undefined, iconRight: undefined },
    });
    expect(wrapper.findComponent(CTIcon).exists()).toBe(false);

    await wrapper.setProps({ iconRight: IconName.MD_NAVIGATION_ARROW_RIGHT });
    expect(wrapper.findComponent(CTIcon).exists()).toBe(true);
  });

  it("passes props to base button", () => {
    const props = {
      href: "href",
      to: "to",
      isLoading: false,
      type,
      variant,
      size,
      isRounded: true,
      isDisabled: false,
    };

    const wrapper = mount(CTButton, {
      props,
    });

    expect(wrapper.findComponent(CTBaseButton).props()).toEqual(props);
  });
});
