import { CalendarDateRange, CTCalendar } from "../calendar";
import type { CalendarProps } from "./types";
import { CTButton } from "../button";
import { computed, ref } from "vue";
import { format } from "date-fns";
import type { Meta, StoryObj } from "@storybook/vue3";
import { stub } from "./stub";
import { getDateRange } from "../../utilities";

const meta: Meta<typeof CTCalendar> = {
  title: "Calendar",
  component: CTCalendar,
};

const template: StoryObj<typeof CTCalendar> = {
  render: (args: CalendarProps) => ({
    components: { CTCalendar, CTButton },
    setup() {
      const modelValue = ref(getDateRange(CalendarDateRange.LAST_30));
      const showCalendar = ref(false);

      const normalizedModelValue = computed((): string[] => {
        return modelValue.value.map((value: Date) =>
          format(value, "dd-MM-yyyy HH:mm:ss"),
        );
      });
      return {
        args,
        modelValue,
        normalizedModelValue,
        showCalendar,
      };
    },
    template: `<div class="flex flex-col gap-4 items-start">
      <CTButton @click.stop="showCalendar = true">Open</CTButton>
      <CTCalendar v-if="showCalendar" v-bind="args" v-model="modelValue" @close="showCalendar = false"/>
    </div>`,
  }),
};

export const Single = {
  ...template,
  args: {
    ...stub,
  },
};

export const Double = {
  ...template,
  args: {
    ...stub,
    isDouble: true,
  },
};

export const Range = {
  ...template,
  args: {
    ...stub,
    isRange: true,
    hasSidebarNav: true,
    isDouble: true,
  },
};

export default meta;
