import { describe, expect, it } from "vitest";
import { mount } from "@vue/test-utils";
import { CaptionCardColor, CTCaptionCard } from "../caption-card";
import { stub as props } from "./stub";
import { useRootStore } from "../../stores/root";
import { ThemeColor } from "../theme";

const { color, to } = props;

describe("CaptionCard", () => {
  it("renders footer", async () => {
    const withoutFooter = mount(CTCaptionCard, {
      props,
    });

    expect(withoutFooter.find({ ref: "footerRef" }).exists()).toStrictEqual(
      false,
    );

    const withFooter = mount(CTCaptionCard, {
      props,
      slots: {
        footer: "Footer!",
      },
    });

    expect(withFooter.find({ ref: "footerRef" }).exists()).toStrictEqual(true);
  });

  it("can be inverted", async () => {
    const wrapper = mount(CTCaptionCard, {
      props: {
        ...props,
        color: CaptionCardColor.GOLD,
      },
      slots: {
        footer: "Footer!",
      },
    });

    const store = useRootStore();
    store.setThemeColor(ThemeColor.LIGHT);
    expect(
      wrapper.find({ ref: "footerRef" }).classes("is-inverted"),
    ).toBeFalsy();

    await wrapper.setProps({ color: CaptionCardColor.SUCCESS });

    expect(
      wrapper.find({ ref: "footerRef" }).classes("is-inverted"),
    ).toBeTruthy();
  });

  it("renders color", async () => {
    const wrapper = mount(CTCaptionCard, {
      props: {},
    });

    expect(
      wrapper.findComponent({ ref: "backgroundRef" }).exists(),
    ).toStrictEqual(false);
    expect(wrapper.classes("color-none")).toStrictEqual(true);

    await wrapper.setProps({ color });
    expect(
      wrapper.findComponent({ ref: "backgroundRef" }).exists(),
    ).toStrictEqual(true);
    expect(wrapper.classes(`color-${color}`)).toStrictEqual(true);
  });

  it("renders link", async () => {
    const wrapper = mount(CTCaptionCard, {
      props: {},
    });

    expect(wrapper.props("to")).toBeFalsy();

    await wrapper.setProps({ to });

    expect(wrapper.props("to")).toStrictEqual(to);
  });
});
