import { ChartType, CTChart } from "../chart";
import type { ChartProps } from "./types";
import type { Meta, StoryObj } from "@storybook/vue3";
import { stub } from "./stub";
import { CTLabel } from "../label";

const meta: Meta<typeof CTChart> = {
  title: "Chart",
  component: CTChart,
};

const template: StoryObj<typeof CTChart> = {
  args: {
    ...stub,
  },
  render: (args: ChartProps) => ({
    components: { CTChart, CTLabel },
    setup() {
      return { args };
    },
    template: `
          <div class="px-6 bg-subdued py-4 rounded shadow-down-xs flex flex-col gap-y-4">
          <div>
            <p class="text-font-alt3">
              Tile requests
            </p>
            <p class="font-mono text-lg font-semibold">
              7,566,991
            </p>
          </div>
          <CTChart class="w-full h-[400px]" v-bind="args" :grid-lines="{x: false, y: 5}"/>
          </div>`,
  }),
};

export const Line = {
  ...template,
};

export const Bar = {
  ...template,
  args: {
    ...stub,
    labels: { x: true, y: false },
    data: {
      ...stub.data,
      max: 100,
      datasets: [
        {
          name: "Route requests",
          type: ChartType.BAR,
          color: "red",
          previous: 0,
          next: 1,
          data: [0, 48, 0, 20, 0, 0, 0, 0, 0, 0, 0, 0],
        },
      ],
    },
  },
};

export const Dot = {
  ...template,
  args: {
    ...stub,
    data: {
      ...stub.data,
      datasets: [
        {
          name: "Route requests",
          type: ChartType.DOT,
          color: "red",
          previous: 0,
          next: 1,
          data: [
            [0, 50],
            [0.1, 10],
            [0.2, 30],
            [0.3, 50],
            [0.4, 70],
            [0.5, 40],
            [0.6, 50],
            [0.7, 20],
            [0.8, 0],
            [0.9, 90],
            [1, 15],
          ],
        },
      ],
    },
  },
};

export default meta;
