import { CTCheckbox } from "../checkbox";
import type { CheckboxProps } from "../checkbox";
import { stub } from "./stub";
import { reactive, ref } from "vue";
import { sameAs } from "@vuelidate/validators";
import useVuelidate from "@vuelidate/core";
import { CTButton } from "../button";
import { ButtonType } from "../base-button";
import type { Meta, StoryObj } from "@storybook/vue3";

const meta: Meta<typeof CTCheckbox> = {
  title: "form/Checkbox",
  component: CTCheckbox,
  argTypes: {
    id: { control: "text" },
    label: { control: "text" },
    sublabel: { control: "text" },
    isBoxed: { control: "boolean" },
    isDisabled: { control: "boolean" },
  },
};

const template: StoryObj<typeof CTCheckbox> = {
  render: (args: CheckboxProps) => ({
    components: { CTCheckbox, CTButton },
    setup() {
      const state = reactive({ terms: false });
      const rules = {
        terms: {
          sameAs: sameAs(ref(true)),
        },
      };
      const v$ = useVuelidate(rules, state);

      return { args, state, v$, ButtonType };
    },
    template: `<div class="flex flex-col gap-y-4 items-start">
      <CTCheckbox v-bind="args" v-model="state.terms" :validation="v$.terms"/>
      <CTButton :type="ButtonType.PRIMARY" @click="v$.$touch()">Submit</CTButton>
    </div>`,
  }),
};

export const Normal = {
  ...template,
  args: {
    ...stub,
  },
};

export const Boxed = {
  ...template,
  args: {
    ...stub,
    isBoxed: true,
  },
};

export default meta;
