import { describe, expect, it } from "vitest";
import { mount } from "@vue/test-utils";
import { ChipSize, ChipVariant, CTChip } from ".";
import { stub } from "./stub";
import { IconName } from "../icon";

const props = {
  ...stub,
};

describe("Chip", () => {
  it("emits click", async () => {
    const wrapper = mount(CTChip, {
      props: { ...props, isDisabled: false },
    });

    await wrapper.trigger("click");
    expect(wrapper.emitted("update:modelValue")).toHaveLength(1);

    await wrapper.setProps({ isDisabled: true });

    await wrapper.trigger("click");
    expect(wrapper.emitted("update:modelValue")).toHaveLength(1);
  });

  it("emits remove", async () => {
    const wrapper = mount(CTChip, {
      props: {
        ...props,
        isDisabled: false,
        variant: ChipVariant.INPUT,
        modelValue: true,
      },
    });

    await wrapper.find({ ref: "clearRef" }).trigger("click");
    expect(wrapper.emitted("remove")).toHaveLength(1);
  });

  it("renders correct icon", async () => {
    const wrapper = mount(CTChip, {
      props: {
        ...props,
        isDisabled: false,
        variant: ChipVariant.INPUT,
        modelValue: true,
      },
    });

    expect(
      wrapper.findComponent({ ref: "iconRef" }).props("name"),
    ).toStrictEqual(IconName.MD_NAVIGATION_CLOSE);

    await wrapper.setProps({ size: ChipSize.SMALL });
    expect(
      wrapper.findComponent({ ref: "iconRef" }).props("name"),
    ).toStrictEqual(IconName.SM_NAVIGATION_CIRCLE_CROSS_FILLED);
  });
});
