export const stub = {
  externalUrl: "https://www.github.com",
  buttonLabel: "View on Github",
  codeList: [
    {
      label: "client.js",
      code: "import { createClient, defaultExchanges } from '@urql/core';\nimport { getCarListQuery, getCarDetailsQuery } from './queries.js';\nimport { renderCarList } from './interface';\n\n/**\n * For the purpose of this example we use urgl - lightweights GraphQL client.\n * To establish a connection with Chargetrip GraphQL API you need to have an API key.\n * The key in this example is a public one and gives an access only to a part of our extensive database.\n * You need a registered `x-client-id` to access the full database.\n * Read more about an authorisation in our documentation (https://docs.chargetrip.com/#authorisation).\n */\nconst headers = {\n  //Replace this x-client-id and app-id with your own to get access to more cars\n  'x-client-id': '5ed1175bad06853b3aa1e492',\n  'x-app-id': '623998b2c35130073829b2d2',\n};\n\nconst client = createClient({\n  url: 'https://api.chargetrip.io/graphql',\n  fetchOptions: {\n    method: 'POST',\n    headers,\n  },\n  exchanges: [...defaultExchanges],\n});\n\n/**\n * You can access a list of all available cars using the `carList` query.\n * In this example we use our playground, which has only 12 cars available.\n * Chargetrip operates an extensive database of EV makes, editions, and versions,\n * each with their specific consumption models.\n * You need a registered x-client-id to access the full car database.\n * You can obtain a registered x-client-id on https://account.chargetrip.com/\n * **/\nexport const getCarList = () => {\n  client\n    .query(getCarListQuery)\n    .toPromise()\n    .then(response => {\n      renderCarList(response.data?.carList);\n    })\n    .catch(error => console.log(error));\n};\n\n/**\n * You can access more detailed information of a specific car using the `car` query.\n * This set of data is a limited set of everything that is available.\n * If you need more you can contact us to get access to our `carPremium` query.\n * @param { string } carId - the id of the car that we want the details of\n */\nexport const getCarDetails = (carId, callback) => {\n  client\n    .query(getCarDetailsQuery, { carId })\n    .toPromise()\n    .then(response => {\n      callback(response.data);\n    })\n    .catch(error => console.log(error));\n};\n",
    },
    {
      label: "index.js",
      code: "import { getCarList } from './client';\nimport { drawMap } from './map';\n\n/**\n * This project shows you how to fetch a car list and render the car details\n * The project structure contains;\n *\n *    - client.js - All networking requests\n *    - interface.js - All interface rendering\n *    - map.js - All map rendering (including routes and waypoints)\n *    - queries.js - The GraphQL queries used in the networking requests\n */\n\ndrawMap();\ngetCarList();\n",
    },
    {
      label: "interface.js",
      code: "import mapboxgl from 'mapbox-gl';\n\nmapboxgl.accessToken = 'pk.eyJ1IjoiY2hhcmdldHJpcCIsImEiOiJjazhpaG8ydTIwNWNpM21ud29xeXc2amhlIn0.rGKgR3JfG9Z5dCWjUI_oGA';\n\nexport const drawMap = () => {\n  new mapboxgl.Map({\n    cooperativeGestures: true,\n    container: 'map',\n    style: 'mapbox://styles/chargetrip/ckgcbf3kz0h8819qki8uwhe0k',\n    zoom: 5,\n    center: [8.1320104, 52.3758916],\n  });\n};\n",
    },
    {
      label: "map.js",
      code: "import mapboxgl from 'mapbox-gl';\n\nmapboxgl.accessToken = 'pk.eyJ1IjoiY2hhcmdldHJpcCIsImEiOiJjazhpaG8ydTIwNWNpM21ud29xeXc2amhlIn0.rGKgR3JfG9Z5dCWjUI_oGA';\n\nexport const drawMap = () => {\n  new mapboxgl.Map({\n    cooperativeGestures: true,\n    container: 'map',\n    style: 'mapbox://styles/chargetrip/ckgcbf3kz0h8819qki8uwhe0k',\n    zoom: 5,\n    center: [8.1320104, 52.3758916],\n  });\n};\n",
    },
    {
      label: "queries.js",
      code: "import qql from 'graphql-tag';\n\nexport const getCarListQuery = qql`\nquery carList {\n  carList(\n    page: 0, \n    size: 12\n  ) {\n    id\n    naming {\n      make\n      model\n      chargetrip_version\n    }\n    media {\n      image {\n        thumbnail_url\n      }\n    }\n  }\n}\n`;\n\nexport const getCarDetailsQuery = qql`\nquery car($carId: ID) {\n  car(id: $carId) {\n    naming {\n      make\n      model\n      chargetrip_version\n    }\n    media {\n      image {\n        url\n      }\n      brand {\n        thumbnail_url\n      }\n    }\n    battery {\n      usable_kwh\n    }\n    range {\n      real\n      best {\n        highway\n        city\n        combined\n      }\n      worst {\n        highway\n        city\n        combined\n      }\n      chargetrip_range {\n        best\n        worst\n      }\n    }\n    routing {\n      fast_charging_support\n    }\n    connectors {\n      standard\n    }\n    performance {\n      acceleration\n      top_speed\n    }\n  }\n}\n`;\n",
    },
  ],
};
