import { describe, expect, it } from "vitest";
import { mount } from "@vue/test-utils";
import { CTContentCard } from "../content-card";
import { CTTag } from "../tag";
import { CTLabel } from "../label";
import { stub } from "./stub";

const props = {
  ...stub,
};

const { label, tag, img, direction } = props;

describe("ContentCard", () => {
  it("renders tag", async () => {
    const wrapper = mount(CTContentCard, {
      props: { ...props, tag: undefined },
    });

    expect(wrapper.findComponent(CTTag).exists()).toBe(false);

    await wrapper.setProps({ tag });

    expect(wrapper.findComponent(CTTag).exists()).toBe(true);
    expect(wrapper.findComponent(CTTag).text()).toBe(tag?.label);
  });

  it("renders img", async () => {
    const wrapper = mount(CTContentCard, {
      props: { ...props, img: undefined },
    });

    expect(wrapper.findComponent({ ref: "imgRef" }).exists()).toBe(false);

    await wrapper.setProps({ img });

    expect(wrapper.findComponent({ ref: "imgRef" }).exists()).toBe(true);
  });

  it("renders label", async () => {
    const wrapper = mount(CTContentCard, {
      props: { ...props, label: undefined },
    });

    expect(wrapper.findComponent(CTLabel).exists()).toBe(false);

    await wrapper.setProps({ label });
    expect(wrapper.findComponent(CTLabel).exists()).toBe(true);
  });

  it("has direction class", async () => {
    const wrapper = mount(CTContentCard, {
      props: { ...props, direction: undefined },
    });

    expect(wrapper.classes("direction-row")).toBe(true);

    await wrapper.setProps({ direction });

    expect(wrapper.classes("direction-row-reverse")).toBe(true);
  });
});
