import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import { CTDeprecationCard } from "../deprecation-card";
import { CTTag } from "../tag";
import { stub } from "./stub";
import { DateFormat, i18n } from "../../utilities/i18n";

const props = {
  ...stub,
};

const { tag, migrationFrom, migrationTo, onDate, tillDate, description } =
  props;

describe("Deprecation card", () => {
  it("renders tag", async () => {
    const wrapper = mount(CTDeprecationCard, { props });

    const tagComponent = wrapper.findComponent(CTTag);
    expect(tagComponent.exists()).toBe(true);
    expect(tagComponent.text()).toBe(tag);
  });

  it("renders migration from", async () => {
    const wrapper = mount(CTDeprecationCard, { props });

    expect(wrapper.find({ ref: "migrationFromRef" }).text()).toBe(
      migrationFrom,
    );
  });

  it("renders migration to", async () => {
    const wrapper = mount(CTDeprecationCard, { props });

    expect(wrapper.find({ ref: "migrationToRef" }).text()).toBe(migrationTo);
  });

  it("renders description", async () => {
    const wrapper = mount(CTDeprecationCard, { props });

    expect(
      wrapper.findComponent({ ref: "descriptionRef" }).vm.props.markdown,
    ).toBe(description);
  });

  it("renders instructions", async () => {
    const wrapper = mount(CTDeprecationCard, { props });

    const [onDateWrapper, tillDateWrapper] = wrapper
      .findComponent({ ref: "instructionsRef" })
      .findAll("strong");

    expect(onDateWrapper.text()).toBe(
      i18n.global.d(onDate, DateFormat.MONTH_YEAR),
    );

    expect(tillDateWrapper.text()).toBe(
      i18n.global.d(tillDate, DateFormat.MONTH_YEAR),
    );
  });
});
