import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import { CTDropdownToggle } from "./index";

const props = {
  label: "Label",
  id: "id",
  modelValue: false,
};

const { label } = props;
describe("DropdownToggle", () => {
  it("can toggle dropdown", async () => {
    const wrapper = mount(CTDropdownToggle, { props, attachTo: document.body });

    expect(wrapper.find({ ref: "containerRef" }).isVisible()).toStrictEqual(
      false,
    );
    await wrapper.find({ ref: "toggleRef" }).trigger("click");

    expect(wrapper.emitted("update:modelValue")?.[0]).toStrictEqual([true]);

    await wrapper.setProps({ modelValue: true });

    expect(wrapper.find({ ref: "containerRef" }).isVisible()).toStrictEqual(
      true,
    );

    await wrapper.find({ ref: "toggleRef" }).trigger("click");

    expect(wrapper.emitted("update:modelValue")?.[1]).toStrictEqual([false]);
  });

  it("can be disabled", async () => {
    const wrapper = mount(CTDropdownToggle, {
      props: { ...props, isDisabled: false },
      attachTo: document.body,
    });

    await wrapper.find({ ref: "toggleRef" }).trigger("click");

    expect(wrapper.emitted("update:modelValue")?.[0]).toStrictEqual([true]);

    await wrapper.setProps({ isDisabled: true });

    await wrapper.find({ ref: "toggleRef" }).trigger("click");

    expect(wrapper.emitted("update:modelValue")?.[1]).toBeFalsy();
  });

  it("can close dropdown by esc", async () => {
    const wrapper = mount(CTDropdownToggle, {
      props: { ...props, modelValue: true },
      attachTo: document.body,
    });

    window.dispatchEvent(new KeyboardEvent("keydown", { key: "Escape" }));

    expect(wrapper.emitted("update:modelValue")?.[0]).toStrictEqual([false]);
  });

  it("can close on click outside", async () => {
    const wrapper = mount(CTDropdownToggle, {
      props: { ...props, modelValue: true },
      attachTo: document.body,
    });

    window.dispatchEvent(new KeyboardEvent("click"));

    expect(wrapper.emitted("update:modelValue")?.[0]).toStrictEqual([false]);
  });

  it("passes label to select", async () => {
    const wrapper = mount(CTDropdownToggle, { props });

    expect(
      wrapper.findComponent({ ref: "selectRef" }).props("label"),
    ).toStrictEqual(label);
  });
});
