import { CTDuoInput, DuoInputOrientation } from "../duo-input";
import type { DuoInputProps } from "../duo-input";
import { CTInput } from "../input";
import { stub } from "./stub";
import { CTButton } from "../button";
import { ButtonType } from "../base-button";
import { reactive, ref } from "vue";
import { minLength, required } from "@vuelidate/validators";
import useVuelidate from "@vuelidate/core";
import type { Meta, StoryObj } from "@storybook/vue3";
import { FormControlSize } from "../form-control/constants";

const meta: Meta<typeof CTDuoInput> = {
  title: "form/DuoInput",
  component: CTDuoInput,
  argTypes: {
    isDisabled: { control: "boolean" },
    orientation: {
      control: "select",
      options: Object.values(DuoInputOrientation),
    },
  },
};

export const Normal: StoryObj<typeof CTDuoInput> = {
  args: {
    ...stub,
  },
  render: (args: DuoInputProps) => ({
    components: { CTDuoInput, CTButton, CTInput },
    setup() {
      const state = reactive({ firstName: "", lastName: "" });
      const rules = {
        firstName: {
          required,
          minLength: minLength(5),
        },
        lastName: {
          required,
          minLength: minLength(5),
        },
      };
      const v$ = useVuelidate(rules, state);

      const binding = ref(args);
      return { binding, args, v$, state, ButtonType, FormControlSize };
    },
    template: `<div class="flex flex-col gap-y-4">
    <CTDuoInput v-bind="binding" :validation="v$" id="hey">
      <CTInput label="" :size="FormControlSize.LARGE" v-model="state.firstName" id="first-name" is-boxed/>
      <CTInput label="" :size="FormControlSize.LARGE" v-model="state.lastName" id="last-name" is-boxed/>
    </CTDuoInput>
    <CTButton :type="ButtonType.PRIMARY" @click="v$.$touch()">Submit</CTButton>
  </div>`,
  }),
};

export default meta;
