import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import CTEmptyState from "./EmptyState.vue";
import { CTIcon } from "../icon";
import { stub } from "./stub";

const props = {
  ...stub,
};

const slotContent = "slot content";
const { icon, label, sublabel } = props;
describe("renders label", () => {
  it("renders label", async () => {
    const wrapper = mount(CTEmptyState, {
      props,
    });

    expect(wrapper.find({ ref: "labelRef" }).text()).toStrictEqual(label);
  });

  it("renders sublabel", async () => {
    const wrapper = mount(CTEmptyState, {
      props,
    });

    expect(wrapper.find({ ref: "sublabelRef" }).text()).toStrictEqual(sublabel);
  });

  it("renders icon", async () => {
    const wrapper = mount(CTEmptyState, {
      props: {
        ...props,
        icon: undefined,
      },
    });

    expect(wrapper.findComponent(CTIcon).exists()).toBe(false);

    await wrapper.setProps({ icon });
    expect(wrapper.findComponent(CTIcon).exists()).toBe(true);
  });

  it("can be inline", async () => {
    const wrapper = mount(CTEmptyState, {
      props,
    });

    expect(wrapper.classes("is-inline")).toStrictEqual(false);
    expect(wrapper.find({ ref: "labelRef" }).html()).contains("h2");

    await wrapper.setProps({ isInline: true });

    expect(wrapper.classes("is-inline")).toStrictEqual(true);
    expect(wrapper.find({ ref: "labelRef" }).html()).contains("p");
  });

  it("renders slot", async () => {
    const wrapper = mount(CTEmptyState, {
      props,
      slots: { default: slotContent },
    });

    expect(wrapper.find({ ref: "slotRef" }).text()).toBe(slotContent);
  });

  it("renders background", async () => {
    const wrapper = mount(CTEmptyState, {
      props,
      slots: { default: slotContent },
    });

    expect(
      wrapper.findComponent({ ref: "backgroundRef" }).exists(),
    ).toStrictEqual(false);

    await wrapper.setProps({ showBackground: true });

    expect(
      wrapper.findComponent({ ref: "backgroundRef" }).exists(),
    ).toStrictEqual(true);
  });
});
