import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import { CTExpandableCard, CTExpandableItem } from "../expandable-card";
import { expandableCardStub } from "./stub";

const props = { ...expandableCardStub };
const { itemList } = props;

describe("ExpandableCard", () => {
  it("renders item list", () => {
    const wrapper = mount(CTExpandableCard, { props });

    expect(wrapper.findAllComponents(CTExpandableItem).length).toBe(
      itemList.length,
    );
  });

  it("can toggle item", async () => {
    const wrapper = mount(CTExpandableCard, { props });

    await wrapper.find("header").trigger("click");

    expect((wrapper.emitted("update:modelValue") as number[][])[0][0]).toEqual([
      0,
    ]);

    await wrapper.setProps({ modelValue: [0] });
    await wrapper.find("header").trigger("click");

    expect((wrapper.emitted("update:modelValue") as number[][])[1][0]).toEqual(
      [],
    );
  });

  it("respects maxOpen prop", async () => {
    const wrapper = mount(CTExpandableCard, {
      props: { ...props, modelValue: [1], maxOpen: 1 },
    });

    await wrapper.find("header").trigger("click");

    expect((wrapper.emitted("update:modelValue") as number[][])[0][0]).toEqual([
      0,
    ]);
  });
});
