import { defineComponent, markRaw, shallowRef } from "vue";
import { storeToRefs } from "pinia";
import type {
  ExpandableCardProps,
  ExpandableItemProps,
} from "../expandable-card";
import { useRootStore } from "../../stores/root";
import { CTTag, TagType } from "../tag";
import { IconName } from "../icon";
import { ThemeColor } from "../theme";
import { CTConnect } from "../connect";

const component = defineComponent({
  components: { CTTag },
  setup() {
    const store = useRootStore();
    const { normalizedThemeColor } = storeToRefs(store);
    return { TagType, IconName, normalizedThemeColor, ThemeColor };
  },
  template: `<CTTag :is-inverted="normalizedThemeColor === ThemeColor.LIGHT" :type="TagType.BASE">Connected</CTTag>`,
});

export const expandableItemStub: ExpandableItemProps = {
  label: "Label",
  sublabel: "Sublabel",
  component: shallowRef(component),
  itemList: new Array(5).fill({
    component: markRaw(CTConnect),
    itemList: [
      { icon: IconName.MD_NAVIGATION_CHEVRON_DOWN, background: "#0A4B58" },
      { icon: IconName.MD_NAVIGATION_CHEVRON_DOWN, background: "#009B0F" },
    ],
    label: "Model name",
    sublabel: "5f043d52bc262f1627fc0315",
  }),
};

export const expandableCardStub: ExpandableCardProps = {
  modelValue: [],
  itemList: ["Aiways", "Audi", "BMW"]
    .map((label) => ({
      ...expandableItemStub,
      label,
    }))
    .map((item) => ({
      ...item,
      sublabel: "Test",
    })),
};
