import { describe, it, expect } from "vitest";
import { flushPromises, mount } from "@vue/test-utils";
import { CTExpandable } from "../expandable";

describe("Expandable", () => {
  it("can be initially closed", async () => {
    const wrapper = mount(CTExpandable, {
      props: { modelValue: false },
    });

    expect(wrapper.vm.height).toBe(0);
  });

  it("can be initially open", async () => {
    const height = 17;
    Object.defineProperty(HTMLElement.prototype, "offsetHeight", {
      value: height,
    });

    const wrapper = mount(CTExpandable, {
      props: { modelValue: true },
    });

    await flushPromises();
    expect(wrapper.find({ ref: "containerRef" }).attributes("style")).toBe(
      `height: ${height}px;`,
    );
  });

  it("can be active", async () => {
    const wrapper = mount(CTExpandable, {
      props: { modelValue: false },
    });

    expect(wrapper.classes("is-active")).toBe(false);
    await wrapper.setProps({ modelValue: true });
    expect(wrapper.classes("is-active")).toBe(true);
  });

  it("can emit modelValue", async () => {
    const wrapper = mount(CTExpandable, {
      props: { modelValue: false },
    });

    await wrapper.find({ ref: "headerRef" }).trigger("click");

    expect(wrapper.emitted("update:modelValue")).toBeTruthy();
  });

  it("can show chevron", async () => {
    const wrapper = mount(CTExpandable, {
      props: { showChevron: false },
    });

    expect(wrapper.findComponent({ ref: "chevronRef" }).exists()).toBe(false);

    await wrapper.setProps({ showChevron: true });
    expect(wrapper.findComponent({ ref: "chevronRef" }).exists()).toBe(true);

    await wrapper.findComponent({ ref: "chevronRef" }).trigger("click");
    expect(wrapper.emitted("update:modelValue")?.[0]).toStrictEqual([true]);

    await wrapper.setProps({ modelValue: true });

    await wrapper.findComponent({ ref: "chevronRef" }).trigger("click");
    expect(wrapper.emitted("update:modelValue")?.[1]).toStrictEqual([false]);
  });
});
