import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import { CTFormControl } from "./index";
import { stub } from "./stub";
import { CTLabel } from "../label";
import type { BaseValidation } from "@vuelidate/core";

const props = { ...stub };
const { label, isDisabled, errorMessages } = props;

describe("FormControl", () => {
  it("renders (sub)label", async () => {
    const wrapper = mount(CTFormControl, {
      props: { ...props, label: undefined, sublabel: undefined },
    });
    expect(wrapper.findComponent(CTLabel).exists()).toBe(false);
    await wrapper.setProps({ label });
    expect(wrapper.findComponent(CTLabel).exists()).toBe(true);
  });

  it("can be disabled", async () => {
    const wrapper = mount(CTFormControl, {
      props: { ...props, isDisabled: false },
    });
    expect(wrapper.classes("is-disabled")).toBe(false);
    await wrapper.setProps({ isDisabled });
    expect(wrapper.classes("is-disabled")).toBe(true);
  });

  it("can be hovered", async () => {
    const wrapper = mount(CTFormControl, {
      props: { ...props, isDisabled: false, isBoxed: true },
      attachTo: document.body,
    });

    expect(wrapper.classes("is-hovered")).toBe(false);
    await wrapper.find({ ref: "elRef" }).trigger("mouseenter");
    await wrapper.trigger("mouseenter");
    expect(wrapper.classes("is-hovered")).toBe(true);
    await wrapper.find({ ref: "elRef" }).trigger("mouseleave");
    await wrapper.trigger("mouseleave");
    expect(wrapper.classes("is-hovered")).toBe(false);
  });

  it("can be error", async () => {
    const wrapper = mount(CTFormControl, {
      props: { ...props, errorMessages: undefined },
    });

    const message = "Errorrr!";

    expect(wrapper.find({ ref: "errorMessageRef" }).exists()).toBe(false);
    expect(wrapper.classes("is-error")).toBe(false);
    await wrapper.setProps({
      validation: {
        $error: true,
        $errors: [{ $message: message }],
        $pending: false,
      } as BaseValidation,
    });
    expect(wrapper.classes("is-error")).toBe(true);
    expect(wrapper.find({ ref: "errorMessageRef" }).exists()).toBe(true);
    expect(wrapper.find({ ref: "errorMessageRef" }).text()).toEqual(message);

    await wrapper.setProps({ errorMessages });
    expect(wrapper.find({ ref: "errorMessageRef" }).text()).toEqual(
      errorMessages![0],
    );
  });
});
