import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import { CTIconButton } from "../icon-button";
import { CTIcon } from "../icon";
import { stub as props } from "./stub";
import { CTBaseButton } from "../base-button";

const { icon, type, variant, size } = props;

describe("IconButton", () => {
  it("emits click", async () => {
    const wrapper = mount(CTIconButton, {
      props: { ...props, isDisabled: undefined },
    });

    await wrapper.trigger("click");

    expect(wrapper.emitted("click")?.length).toBe(1);

    await wrapper.trigger("click");

    expect(wrapper.emitted("click")?.length).toBe(2);

    await wrapper.trigger("click");
    await wrapper.trigger("click");

    expect(wrapper.emitted("click")?.length).toBe(4);
  });

  it("renders icon", async () => {
    const wrapper = mount(CTIconButton, {
      props: { ...props },
    });
    expect(wrapper.findComponent(CTIcon).props("name")).toStrictEqual(icon);
  });

  it("passes props to base button", () => {
    const props = {
      href: "href",
      to: "to",
      type,
      variant,
      size,
      isLoading: false,
      isRounded: true,
      isDisabled: false,
    };

    const wrapper = mount(CTIconButton, {
      props: { icon, ...props },
    });

    expect(wrapper.findComponent(CTBaseButton).props()).toEqual(props);
  });
});
