import { CTInput, InputType } from "../input";
import type { InputProps } from "../input";
import { stub } from "./stub";
import { reactive } from "vue";
import useVuelidate from "@vuelidate/core";
import { helpers, minLength, required } from "@vuelidate/validators";
import { CTButton } from "../button";
import { ButtonType } from "../base-button";
import type { Meta, StoryObj } from "@storybook/vue3";
import { iconArgTypes } from "../../utilities/storybook";
import { FormControlSize } from "../form-control/constants";

const meta: Meta<typeof CTInput> = {
  title: "form/Input",
  component: CTInput,
  argTypes: {
    id: { control: "text" },
    label: { control: "text" },
    type: { control: "select", options: Object.values(InputType) },
    size: { control: "select", options: Object.values(FormControlSize) },
    isBoxed: { control: "boolean" },
    ...iconArgTypes,
  },
};

const template: StoryObj<typeof CTInput> = {
  // @ts-ignore:next-line
  render: (args: InputProps<string>) => ({
    components: { CTInput, CTButton },
    setup() {
      const state = reactive({ firstName: 0.3 });
      const rules = {
        firstName: {
          required: helpers.withMessage("This field cannot be empty", required),
          minLength: minLength(5),
        },
      };
      const v$ = useVuelidate(rules, state);

      const update = (value: number): void => {
        state.firstName = value;
      };
      return { args, v$, state, ButtonType, update, FormControlSize };
    },
    template: `<div class="flex flex-col items-start gap-4">
    {{state.firstName}}
      <div class="w-[300px] flex gap-3">
        <CTInput class="flex-1" id="input" label="" v-bind="args" v-model="state.firstName" :validation="v$.firstName" :size="FormControlSize.LARGE" is-boxed>
          <template #inputPrefix>
            <p class="whitespace-nowrap">
                Input fasdfasdfadsfasdf
            </p>
          </template>
        </CTInput>
        <CTInput class="flex-1" id="input" label="" v-bind="args" v-model="state.firstName" :validation="v$.firstName" :size="FormControlSize.LARGE" is-boxed>
          <template #inputPrefix>
            <p class="whitespace-nowrap">
              Input fasdfasdfadsfasdf
            </p>
          </template>
        </CTInput>
      </div>
    <div class="flex gap-2">
        <CTButton :type="ButtonType.PRIMARY" @click="v$.$touch()">Submit</CTButton>
        <CTButton :type="ButtonType.PRIMARY" @click="state.firstName = 10_000">Reset</CTButton>
    </div>
  </div>`,
  }),
};

export const Normal = {
  ...template,
  args: {
    ...stub,
  },
};

export const Boxed = {
  ...template,
  args: {
    ...stub,
    type: InputType.SEARCH,
    hotkey: undefined,
    maskedOptions: undefined,
    isBoxed: true,
  },
};

export const Compact = {
  ...template,
  args: {
    ...stub,
    isRounded: true,
    hotkey: undefined,
    isBoxed: true,
  },
};
export const Number = {
  ...template,
  args: {
    ...stub,
    type: InputType.NUMBER,
    maskedOptions: undefined,
    hotkey: undefined,
    isRounded: true,
    isBoxed: true,
  },
};

export default meta;
