import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import CTLabel from "./Label.vue";
import { stub } from "./stub";
import { cleanHTML } from "../../utilities/vitest";

const props = { ...stub };
const { label, sublabel, id } = props;

describe("Label", () => {
  it("renders label", async () => {
    const wrapper = mount(CTLabel, { props });

    expect(wrapper.findComponent({ ref: "labelRef" }).exists()).toBe(true);
  });

  it("renders slot", async () => {
    const slot = "slot";
    const wrapper = mount(CTLabel, { props, slots: { default: slot } });

    expect(cleanHTML(wrapper.text().replace(/ /g, ""))).toBe(
      cleanHTML(`${label}${slot}${sublabel}`),
    );
  });

  it("renders sublabel", async () => {
    const wrapper = mount(CTLabel, {
      props: { ...props, sublabel: undefined },
    });

    expect(wrapper.find({ ref: "sublabelRef" }).exists()).toBe(false);

    await wrapper.setProps({ sublabel });
    expect(wrapper.findComponent({ ref: "sublabelRef" }).exists()).toBe(true);
  });

  it("has for attribute", async () => {
    const wrapper = mount(CTLabel, {
      props: { ...props, id: undefined },
    });

    expect(wrapper.attributes("for")).toBeFalsy();
    expect(wrapper.html().includes("<label")).toBe(false);

    await wrapper.setProps({ id });

    expect(wrapper.attributes("for")).toBe(id);
    expect(wrapper.html().includes("<label")).toBe(true);
  });
});
