import { describe, expect, it } from "vitest";
import { mount } from "@vue/test-utils";
import { CTLink } from "./index";
import { stub } from "./stub";

const { to, href, fallbackComponent } = stub;

describe("Link", () => {
  it("renders slot", async () => {
    const label = "slot content";
    const wrapper = mount(CTLink, {
      slots: { default: label! },
    });

    expect(wrapper.text()).toBe(label);
  });

  it("renders to", async () => {
    const wrapper = mount(CTLink, { props: { to } });

    expect(wrapper.attributes("href")).toBe(to);
  });

  it("renders href", async () => {
    const wrapper = mount(CTLink, { props: { href, to: undefined } });

    expect(wrapper.attributes("href")).toBe(href);
    expect(wrapper.attributes("target")).toBe("_blank");
  });

  it("renders button", async () => {
    const wrapper = mount(CTLink, { props: { fallbackComponent } });

    expect(wrapper.html().includes(fallbackComponent!)).toBe(true);
  });

  it("can be nuxt", async () => {
    const wrapper = mount(CTLink, {
      props: {
        ...stub,
      },
      global: {
        provide: {
          isNuxt: true,
        },
      },
    });

    expect(wrapper.attributes("is")).toStrictEqual("NuxtLink");
  });
});
