import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import CTListItem from "./ListItem.vue";
import { CTLabel } from "../label";
import { CTIcon } from "../icon";
import { stub } from "./stub";
import { ListItemType } from "./constants";

const props = { ...stub };
const { to, icon } = props;

describe("List item", () => {
  it("renders href", async () => {
    const wrapper = mount(CTListItem, {
      props,
    });

    expect(wrapper.attributes("href")).toBe(to);
  });

  it("renders label", async () => {
    const wrapper = mount(CTListItem, {
      props,
    });

    const labelComponent = wrapper.findComponent(CTLabel);

    expect(labelComponent.exists()).toBe(true);
  });

  it("renders icon", async () => {
    const wrapper = mount(CTListItem, {
      props: { ...props, icon: undefined },
    });

    expect(wrapper.findComponent(CTIcon).exists()).toBe(false);
    await wrapper.setProps({ icon });
    expect(wrapper.findComponent(CTIcon).exists()).toBe(true);
  });

  it("can be disabled", async () => {
    const wrapper = mount(CTListItem, {
      props: { ...props, isDisabled: undefined },
    });

    expect("disabled" in wrapper.attributes()).toBe(false);

    await wrapper.setProps({ isDisabled: true });

    expect("disabled" in wrapper.attributes()).toBe(true);
  });

  it("has type class", async () => {
    const wrapper = mount(CTListItem, {
      props: { ...props, isDisabled: undefined },
    });

    expect(wrapper.classes("type-default")).toBe(true);
    await wrapper.setProps({ type: ListItemType.WARNING });
    expect(wrapper.classes("type-warning")).toBe(true);
  });

  it("can be active", async () => {
    const wrapper = mount(CTListItem, {
      props: { ...props },
    });

    expect(wrapper.classes("is-active")).toBe(false);
    await wrapper.setProps({ isActive: true });

    expect(wrapper.classes("is-active")).toBe(true);
  });
});
