import { CTMegaMenuItem } from "../mega-menu";
import { mount } from "@vue/test-utils";
import { describe, it, expect } from "vitest";
import { menuList } from "./stub";

const props = menuList[0];
const { to, label, sublabel, image } = props;
describe("MegaMenuItem", () => {
  it("renders label", () => {
    const wrapper = mount(CTMegaMenuItem, { props });

    expect(wrapper.find({ ref: "labelRef" }).text()).toStrictEqual(label);
  });

  it("renders sublabel", () => {
    const wrapper = mount(CTMegaMenuItem, { props });

    expect(wrapper.find({ ref: "sublabelRef" }).text()).toStrictEqual(sublabel);
  });

  it("renders link", () => {
    const wrapper = mount(CTMegaMenuItem, { props });

    expect(wrapper.props("to")).toStrictEqual(to);
  });

  it("can be disabled", async () => {
    const wrapper = mount(CTMegaMenuItem, {
      props: { ...props, isDisabled: false },
    });

    expect(wrapper.classes("is-disabled")).toBeFalsy();

    await wrapper.setProps({ isDisabled: true });
    expect(wrapper.classes("is-disabled")).toBeTruthy();
  });

  // it("renders icon", async () => {
  //   const wrapper = mount(CTMegaMenuItem, {
  //     props: { ...props, isDisabled: false, icon: undefined },
  //   });
  //
  //   expect(wrapper.findComponent({ ref: "iconRef" })).toStrictEqual(false);
  //
  //   await wrapper.setProps({ i });
  //   expect(wrapper.findComponent({ ref: "iconRef" })).toStrictEqual(true);
  // });

  it("can be image", async () => {
    const wrapper = mount(CTMegaMenuItem, {
      props,
    });

    expect(wrapper.findComponent({ ref: "imageRef" }).exists()).toStrictEqual(
      true,
    );

    expect(
      wrapper.findComponent({ ref: "imageRef" }).props("src"),
    ).toStrictEqual(image);
  });
});
