import { describe, it, expect } from "vitest";
import { CTMenuDropdown } from "./index";
import { CTListItem } from "./../list-item";
import { CTIcon, IconName } from "./../icon";
import { mount } from "@vue/test-utils";
import { CTTag, TagType } from "../tag";

describe("MenuDropdown", () => {
  it("renders the header labels", async () => {
    const wrapper = mount(CTMenuDropdown, {
      props: {
        show: true,
      },
    });

    expect(wrapper.find({ ref: "headerRef" }).exists()).toBe(false);

    await wrapper.setProps({
      header: {
        icon: IconName.MD_CONTROLS_THEME_DARK,
        label: "Label",
        sublabel: "Header sublabel",
      },
    });

    expect(wrapper.find({ ref: "headerRef" }).exists()).toBe(true);
  });

  it("renders a header icon image", async () => {
    const wrapper = mount(CTMenuDropdown, {
      props: {
        show: true,
        header: {
          icon: IconName.MD_CONTROLS_THEME_LIGHT,
          label: "",
        },
      },
    });

    expect(wrapper.findComponent(CTIcon)).toBeTruthy();
  });

  it.each([
    ["Gideon van Dijk", "GD"],
    ["Pieter Waller", "PW"],
    ["Chargetrip", "C"],
  ])('renders header icon label of "%s" as "%s"', (name, expected) => {
    const wrapper = mount(CTMenuDropdown, {
      props: {
        show: true,
        header: {
          label: name,
        },
      },
    });

    const headerIcon = wrapper.find({ ref: "headerIconRef" });
    expect(headerIcon.text()).toBe(expected);
  });

  it("renders menu items", async () => {
    const wrapper = mount(CTMenuDropdown, {
      props: {
        show: true,
        items: [
          {
            label: "Example A",
            to: "/example-a",
          },
          {
            label: "Example B",
            to: "/example-b",
          },
          {
            label: "Example C",
            to: "/example-c",
          },
        ],
      },
    });

    expect(wrapper.findAllComponents(CTListItem)).toHaveLength(3);
  });

  it("renders an empty string for iconLabel if no header exists", async () => {
    const wrapper = mount(CTMenuDropdown, {
      props: {
        show: true,
      },
    });

    expect(wrapper.vm.iconLabel).toBe("");
  });

  it("renders a tag in a sub item if tag label exists", async () => {
    const wrapper = mount(CTMenuDropdown, {
      props: {
        show: true,
        items: [
          {
            label: "Open dashboard",
            to: "/open-dashboard",
            icon: IconName.MD_CONTENT_DASHBOARD,
          },
          {
            label: "Manage plan",
            to: "/manage-plan",
            icon: IconName.MD_NAVIGATION_CIRCLE_ARROW_UP,
            tagLabel: "Go Pro",
            tagType: TagType.SHINY,
          },
        ],
      },
    });

    expect(wrapper.findComponent(CTTag)).toBeTruthy();
  });
});
