import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import { CTDeveloperPortalControls } from "./index";
import { useRootStore } from "../../stores/root";
import { nextTick } from "vue";
import { testingPinia } from "../../test";

describe("DeveloperPortalControls", () => {
  it("emits a 'click-search' event on clicking the search icon", async () => {
    const wrapper = mount(CTDeveloperPortalControls, {});

    const iconSearch = wrapper.findComponent({ ref: "iconSearchRef" });
    await iconSearch.trigger("click");

    expect(wrapper.emitted()).toHaveProperty("click-search");
  });

  it("shows right button", async () => {
    const wrapper = mount(CTDeveloperPortalControls, {});

    const store = useRootStore(testingPinia);
    expect(
      wrapper.findComponent({ ref: "buttonSignInRef" }).exists(),
    ).toStrictEqual(true);

    expect(
      wrapper.findComponent({ ref: "dashboardButtonRef" }).exists(),
    ).toStrictEqual(false);

    store.setToken("test");

    await nextTick();

    expect(
      wrapper.findComponent({ ref: "buttonSignInRef" }).exists(),
    ).toStrictEqual(false);

    expect(
      wrapper.findComponent({ ref: "dashboardButtonRef" }).exists(),
    ).toStrictEqual(true);
  });
});
