import { describe, expect, it } from "vitest";
import { mount } from "@vue/test-utils";
import { CTThemeSelector } from "./index";
import { ThemeColor } from "../theme";
import { useRootStore } from "../../stores/root";
import { CTListItem } from "../list-item";

describe("ThemeSelector", () => {
  it("hides theme dropdown on outside click", async () => {
    const wrapper = mount(CTThemeSelector, { attachTo: document.body });

    expect(wrapper.vm.isActive).toBe(false);
    await wrapper.findComponent({ ref: "iconThemeRef" }).trigger("click");

    expect(wrapper.vm.isActive).toBe(true);
    window.dispatchEvent(new MouseEvent("click"));
    expect(wrapper.vm.isActive).toBe(false);
  });

  it.each([
    [0, ThemeColor.SYSTEM],
    [1, ThemeColor.LIGHT],
    [2, ThemeColor.DARK],
  ])("theme list item %i sets the theme to %s", async (index, expected) => {
    const wrapper = mount(CTThemeSelector);

    const store = useRootStore();
    expect(store.themeColor).toBe(ThemeColor.SYSTEM);

    const iconTheme = wrapper.findComponent({ ref: "iconThemeRef" });
    await iconTheme.trigger("click");

    const items = wrapper
      .findComponent({ ref: "themeDropdownRef" })
      .findAllComponents(CTListItem);

    await items[index].trigger("click");
    expect(store.themeColor).toBe(expected);
  });
});
