import { describe, expect, it } from "vitest";
import { mount } from "@vue/test-utils";
import { CTChapterModal } from "./index";

describe("Modal", () => {
  it("renders main slot", async () => {
    const slotContent = "Main content";

    const wrapper = mount(CTChapterModal, { slots: { main: slotContent } });

    expect(wrapper.find({ ref: "mainRef" }).text()).toBe(slotContent);
  });

  it("emits showAside", async () => {
    const wrapper = mount(CTChapterModal);

    expect(wrapper.classes("show-aside")).toStrictEqual(false);
    expect(wrapper.classes("show-main")).toStrictEqual(true);

    await wrapper.findComponent({ ref: "showAsideRef" }).trigger("click");

    expect(wrapper.emitted("update:showAside")?.[0]).toStrictEqual([true]);

    await wrapper.setProps({ showAside: true });

    expect(wrapper.classes("show-aside")).toStrictEqual(true);
    expect(wrapper.classes("show-main")).toStrictEqual(false);
  });

  it("renders main header slot", async () => {
    const slotContent = "Main header";

    const wrapper = mount(CTChapterModal, {
      slots: { mainHeader: slotContent },
    });

    expect(wrapper.find({ ref: "mainHeaderRef" }).text()).toBe(slotContent);
  });

  it("renders main slot", async () => {
    const slotContent = "Aside content";

    const wrapper = mount(CTChapterModal, { slots: { aside: slotContent } });

    expect(wrapper.find({ ref: "asideRef" }).text()).toBe(slotContent);
  });

  it("renders main header slot", async () => {
    const slotContent = "Aside header";

    const wrapper = mount(CTChapterModal, {
      slots: { asideHeader: slotContent },
    });

    expect(wrapper.find({ ref: "asideHeaderRef" }).text()).toBe(slotContent);
  });

  it("has reversed class", async () => {
    const wrapper = mount(CTChapterModal);

    expect(wrapper.classes("is-reversed")).toBe(false);

    await wrapper.setProps({ isReversed: true });

    expect(wrapper.classes("is-reversed")).toBe(true);
  });
});
