import { describe, expect, it } from "vitest";
import { mount } from "@vue/test-utils";
import { CTModal, ModalType } from "./index";
import { modalStub } from "./stub";

const { size } = modalStub;

describe("Modal", () => {
  it("has size class", async () => {
    const wrapper = mount(CTModal);

    expect(wrapper.classes("size-md")).toBe(true);

    await wrapper.setProps({ size });
    expect(wrapper.classes(`size-${size}`)).toBe(true);
  });

  it("renders image", async () => {
    const wrapper = mount(CTModal);

    expect(
      wrapper.findComponent({ ref: "modalBgRef" }).props("src"),
    ).toStrictEqual("/modal/default.png");

    await wrapper.setProps({ type: ModalType.WARNING });

    expect(
      wrapper.findComponent({ ref: "modalBgRef" }).props("src"),
    ).toStrictEqual("/modal/warning.png");

    await wrapper.setProps({ type: ModalType.ERROR });

    expect(
      wrapper.findComponent({ ref: "modalBgRef" }).props("src"),
    ).toStrictEqual("/modal/error.png");
  });

  it("renders slot", async () => {
    const slotContent = "Slot content";

    const wrapper = mount(CTModal, { slots: { default: slotContent } });

    expect(wrapper.text()).toBe(slotContent);
  });

  it("can emit close with Escape", async () => {
    const wrapper = mount(CTModal, { attachTo: document.body });

    window.dispatchEvent(new KeyboardEvent("keydown", { key: "Escape" }));
    expect(wrapper.emitted().close).toBeTruthy();
  });
});
