import { CTRadio } from "../radio";
import type { RadioProps } from "../radio";
import { stub } from "./stub";
import { reactive } from "vue";
import { required } from "@vuelidate/validators";
import useVuelidate from "@vuelidate/core";
import { CTButton } from "../button";
import { ButtonType } from "../base-button";
import type { Meta, StoryObj } from "@storybook/vue3";

const meta: Meta<typeof CTRadio> = {
  title: "form/Radio",
  argTypes: {
    id: { control: "text" },
    name: { control: "text" },
    label: { control: "text" },
    sublabel: { control: "text" },
    isDisabled: { control: "boolean" },
    isBoxed: { control: "boolean" },
  },
};

const template: StoryObj<typeof CTRadio> = {
  args: {
    ...stub,
  },
  render: (args: RadioProps) => ({
    components: { CTRadio, CTButton },
    setup() {
      const state = reactive({ terms: "" });
      const rules = {
        terms: {
          required,
        },
      };
      const v$ = useVuelidate(rules, state);

      return { args, state, v$, ButtonType };
    },
    template: `<div class="flex flex-col gap-y-4 items-start">
      <CTRadio v-bind="args" name="option 1" v-model="state.terms" :validation="v$.terms"/>
      <CTRadio v-bind="args" name="option 2" v-model="state.terms" :validation="v$.terms"/>
      {{ state.terms }}
      <CTButton :type="ButtonType.PRIMARY" @click="v$.$touch()">Submit</CTButton>
    </div>`,
  }),
};

export const Normal = {
  ...template,
};

export const Boxed = {
  ...template,
  args: {
    ...stub,
    isBoxed: true,
  },
};
export default meta;
