import { describe, expect, it } from "vitest";
import { mount } from "@vue/test-utils";
import { CTReleaseNoteCard } from "../release-note-card";
import { stub } from "./stub";
import { DateFormat, i18n } from "../../utilities/i18n";

const props = {
  ...stub,
};

const { label, version, date, applicationList } = props;

describe("ReleaseNoteCard", () => {
  it("renders label", async () => {
    const wrapper = mount(CTReleaseNoteCard, { props });

    expect(wrapper.find({ ref: "labelRef" }).text()).toBe(label);
  });

  it("renders version", async () => {
    const wrapper = mount(CTReleaseNoteCard, { props });

    expect(wrapper.find({ ref: "versionRef" }).text()).toBe(version);
  });

  it("renders date", async () => {
    const wrapper = mount(CTReleaseNoteCard, { props });

    expect(wrapper.find({ ref: "dateRef" }).text()).toBe(
      i18n.global.d(date, DateFormat.DAY_MONTH_YEAR),
    );

    const date2 = new Date();
    await wrapper.setProps({ date: date2 });

    expect(wrapper.find({ ref: "dateRef" }).text()).toBe(
      i18n.global.d(date, DateFormat.DAY_MONTH_YEAR),
    );
  });

  it("renders applications", async () => {
    const wrapper = mount(CTReleaseNoteCard, {
      props: { ...props, applicationList: [] },
    });

    expect(wrapper.find({ ref: "applicationRef" }).exists()).toBe(false);

    await wrapper.setProps({ applicationList });

    expect(wrapper.findAll(".highlight-box").length).toBe(
      applicationList?.length,
    );
  });

  it("renders slot", async () => {
    const slotContent = "Slot content";

    const wrapper = mount(CTReleaseNoteCard, {
      slots: {
        default: slotContent,
      },
      props,
    });

    expect(wrapper.findComponent({ ref: "slotRef" }).text()).toBe(slotContent);
  });

  it("renders beta", async () => {
    const wrapper = mount(CTReleaseNoteCard, {
      props: { ...props, isBeta: false },
    });

    expect(wrapper.findComponent({ ref: "betaRef" }).exists()).toBe(false);
    await wrapper.setProps({ isBeta: true });
    expect(wrapper.findComponent({ ref: "betaRef" }).exists()).toBe(true);
  });
});
