import { CTReleaseNoteCard, Application } from "../release-note-card";
import type { ReleaseNoteCardProps } from "../release-note-card";
import { CTContent } from "../content";
import { CTGrid } from "../grid";
import { CTWarningBanner } from "../banner";
import type { Meta, StoryObj } from "@storybook/vue3";
import { stub } from "./stub";

const meta: Meta<typeof CTReleaseNoteCard> = {
  title: "Card/ReleaseNote",
  component: CTReleaseNoteCard,
  argTypes: {
    label: { control: "text" },
    version: { control: "text" },
    date: { control: "date" },
    applicationList: {
      control: "multi-select",
      options: Object.values(Application),
    },
  },
};

export const ReleaseNote: StoryObj<typeof CTReleaseNoteCard> = {
  args: {
    ...stub,
  },
  render: (args: ReleaseNoteCardProps) => ({
    components: { CTReleaseNoteCard, CTWarningBanner, CTContent, CTGrid },
    setup() {
      const markdown = `### ⚡️️ New features
- Added the new query navigationMapping that converts a route to navigation instructions for a specified mapping provider. Currently Mapbox is supported, other mapping providers will follow.
- Added an all new dark and light mode to the dashboard.
- Added date range input fields to the dashboard calendar dropdown.
- Added the ability to remove your account from the dashboard.
- Added the ability to remove your own projects from the dashboard.

### ✨️ Improvements
- Improved schema descriptions for fast_charge_support
- Improved stability by fixing various small bugs

### 🐞 Bug fixes
- Fixed a bug in stationStats on the stations count grouped by amenities.`;
      return { args, markdown };
    },
    template: `
      <CTReleaseNoteCard v-bind="args" v-for="key in 2" :key="key" is-beta>
        <CTContent :markdown="markdown"/>
      </CTReleaseNoteCard>
    `,
  }),
};

export default meta;
