import type { SchemaFieldBlockProps } from "./types";

export const stub: SchemaFieldBlockProps = {
  label: "vehicleList",
  sublabel: "[BETA] Get a full list of vehicles",
  type: "VehicleList",
  isEnum: false,
  isDeprecated: false,
  isRequired: false,
  argumentList: [
    {
      label: "search",
      sublabel:
        "Search for vehicles by make, model, version and chargetrip version",
      type: "String",
      defaultValue: null,
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [],
    },
    {
      label: "filter",
      sublabel: "Filter vehicle result",
      type: "VehicleListFilter",
      defaultValue: null,
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [
        {
          label: "availability",
          sublabel: "Availability of a vehicle",
          type: "VehicleAvailabilityStatus",
          defaultValue: null,
          isEnum: true,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [
            {
              label: "no_longer_available",
              sublabel: "Vehicle no longer for sale in any market / region",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "available",
              sublabel:
                "Vehicle currently for sale in at least one market / region",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "release_date_announced_preorderable",
              sublabel:
                "Vehicle expected in market from Date_From (estimated), pre-order open",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "release_date_announced",
              sublabel:
                "Vehicle expected in market from Date_From (estimated), pre-order unknown or not open",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "concept_vehicle_preorderable",
              sublabel:
                "Concept vehicle, nearing production and/or confirmed, pre-order open",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "concept_vehicle",
              sublabel:
                "Concept vehicle, nearing production and/or confirmed, pre-order unknown or not open",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "concept_vehicle_release_date_tba_preorderable",
              sublabel:
                "Concept vehicle, not close to production and/or unconfirmed, pre-order open",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "concept_vehicle_release_date_tba",
              sublabel:
                "Concept vehicle, not close to production and/or unconfirmed, pre-order unknown",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "uncertain",
              sublabel:
                "Status uncertain, introduction date and/or pricing unclear",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
          ],
        },
        {
          label: "drivetrain",
          sublabel: "Drivetrain type of a vehicle",
          type: "VehicleDrivetrainType",
          defaultValue: null,
          isEnum: true,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [
            {
              label: "BEV",
              sublabel: "Battery Electric Vehicle",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "EREV",
              sublabel: "Extended Range Electric Vehicle",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "HEV",
              sublabel: "Hybrid Electric Vehicle",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "PHEV",
              sublabel: "Plug-in Hybrid Electric Vehicle",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
          ],
        },
        {
          label: "connect",
          sublabel: "Information about vehicle connectivity",
          type: "ConnectFilter",
          defaultValue: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [
            {
              label: "providers",
              sublabel:
                "List of connectivity providers to which a vehicle can connect",
              type: "ConnectProvider",
              defaultValue: null,
              isEnum: true,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [
                {
                  label: "Enode",
                  sublabel: null,
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
              ],
            },
          ],
        },
      ],
    },
    {
      label: "country",
      sublabel:
        "ISO-3166 alpha-2 country code to apply localization on vehicle data if available",
      type: "CountryCodeAlpha2",
      defaultValue: null,
      isEnum: true,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [
        {
          label: "AD",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AE",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AF",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AG",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AI",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AL",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AN",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AO",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AQ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AR",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AS",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AT",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AU",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AW",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AX",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "AZ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BA",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BB",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BD",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BE",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BF",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BG",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BH",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BI",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BJ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BL",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BN",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BO",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BQ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BR",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BS",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BT",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BV",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BW",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BY",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "BZ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CA",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CC",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CD",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CF",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CG",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CH",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CI",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CK",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CL",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CN",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CO",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CR",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CS",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CU",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CV",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CW",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CX",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CY",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "CZ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "DE",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "DJ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "DK",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "DM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "DO",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "DZ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "EC",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "EE",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "EG",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "EH",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "ER",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "ES",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "ET",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "FI",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "FJ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "FK",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "FM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "FO",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "FR",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GA",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GB",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GD",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GE",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GF",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GG",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GH",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GI",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GL",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GN",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GP",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GQ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GR",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GS",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GT",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GU",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GW",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "GY",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "HK",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "HM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "HN",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "HR",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "HT",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "HU",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "ID",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "IE",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "IL",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "IM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "IN",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "IO",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "IQ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "IR",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "IS",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "IT",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "JE",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "JM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "JO",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "JP",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "KE",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "KG",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "KH",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "KI",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "KM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "KN",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "KP",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "KR",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "KW",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "KY",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "KZ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "LA",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "LB",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "LC",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "LI",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "LK",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "LR",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "LS",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "LT",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "LU",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "LV",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "LY",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MA",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MC",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MD",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "ME",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MF",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MG",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MH",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MK",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "ML",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MN",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MO",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MP",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MQ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MR",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MS",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MT",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MU",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MV",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MW",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MX",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MY",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "MZ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "NA",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "NC",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "NE",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "NF",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "NG",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "NI",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "NL",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "NO",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "NP",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "NR",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "NU",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "NZ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "OM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "PA",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "PE",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "PF",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "PG",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "PH",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "PK",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "PL",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "PM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "PN",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "PR",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "PS",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "PT",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "PW",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "PY",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "QA",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "RE",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "RKS",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "RO",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "RS",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "RU",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "RW",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SA",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SB",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SC",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SD",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SE",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SG",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SH",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SI",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SJ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SK",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SL",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SN",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SO",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SR",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SS",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "ST",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SV",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SX",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SY",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "SZ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TC",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TD",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TF",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TG",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TH",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TJ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TK",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TL",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TN",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TO",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TR",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TT",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TV",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TW",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "TZ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "UA",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "UG",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "UM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "US",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "UY",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "UZ",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "VA",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "VC",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "VE",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "VG",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "VI",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "VN",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "VU",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "WF",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "WS",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "YE",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "YT",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "ZA",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "ZM",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "ZW",
          sublabel: null,
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
      ],
    },
    {
      label: "size",
      sublabel: "Number of elements (count) to return, default: 10",
      type: "Int",
      defaultValue: null,
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [],
    },
    {
      label: "page",
      sublabel: "Page number to return, default: 0",
      type: "Int",
      defaultValue: null,
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [],
    },
  ],
  childList: [
    {
      label: "id",
      sublabel: "Vehicles unique ID",
      type: "ID",
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [],
    },
    {
      label: "naming",
      sublabel: "Naming of the vehicle",
      type: "VehicleListNaming",
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [
        {
          label: "make",
          sublabel: "Vehicle manufacturer name",
          type: "String",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "model",
          sublabel: "Vehicle model name",
          type: "String",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "version",
          sublabel: "Version, edition or submodel of the vehicle",
          type: "String",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "edition",
          sublabel: "Another submodel level of the vehicle",
          type: "String",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "chargetrip_version",
          sublabel:
            "Vehicle model version. Added by Chargetrip as an alternative for when a vehicle manufacturer does not provide an version name, or uses the same version name across all trims or consecutive years",
          type: "String",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
      ],
    },
    {
      label: "drivetrain",
      sublabel: "Drivetrain of the vehicle",
      type: "VehicleDrivetrain",
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [
        {
          label: "type",
          sublabel: "Type of drivetrain",
          type: "VehicleDrivetrainType",
          isEnum: true,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [
            {
              label: "BEV",
              sublabel: "Battery Electric Vehicle",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "EREV",
              sublabel: "Extended Range Electric Vehicle",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "HEV",
              sublabel: "Hybrid Electric Vehicle",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "PHEV",
              sublabel: "Plug-in Hybrid Electric Vehicle",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
          ],
        },
      ],
    },
    {
      label: "connectors",
      sublabel: "Connectors available for the vehicle",
      type: "VehicleConnector",
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [
        {
          label: "standard",
          sublabel: "Connector type, known as connector standard in OCPI",
          type: "ConnectorType",
          isEnum: true,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [
            {
              label: "CHADEMO",
              sublabel: "The connector type is CHAdeMO, DC",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_A",
              sublabel:
                'Standard/domestic household, type "A", NEMA 1-15, 2 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_B",
              sublabel:
                'Standard/domestic household, type "B", NEMA 5-15, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_C",
              sublabel:
                'Standard/domestic household, type "C", CEE 7/17, 2 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_D",
              sublabel: 'Standard/domestic household, type "D", 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_E",
              sublabel: 'Standard/domestic household, type "E", CEE 7/5 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_F",
              sublabel:
                'Standard/domestic household, type "F", CEE 7/4, Schuko, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_G",
              sublabel:
                'Standard/domestic household, type "G", BS 1363, Commonwealth, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_H",
              sublabel: 'Standard/domestic household, type "H", SI-32, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_I",
              sublabel:
                'Standard/domestic household, type "I", AS 3112, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_J",
              sublabel:
                'Standard/domestic household, type "J", SEV 1011, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_K",
              sublabel:
                'Standard/domestic household, type "K", DS 60884-2-D1, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_L",
              sublabel:
                'Standard/domestic household, type "L", CEI 23-16-VII, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_M",
              sublabel: 'Standard/Domestic household, type "M", BS 546, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_N",
              sublabel:
                'Standard/Domestic household, type "N", NBR 14136, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_O",
              sublabel:
                'Standard/Domestic household, type "O", TIS 166-2549, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_60309_2_single_16",
              sublabel:
                "IEC 60309-2 Industrial connector single phase 16 amperes (usually blue)",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_60309_2_three_16",
              sublabel:
                "IEC 60309-2 Industrial connector three phase 16 amperes (usually red)",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_60309_2_three_32",
              sublabel:
                "IEC 60309-2 Industrial connector three phase 32 amperes (usually red)",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_60309_2_three_64",
              sublabel:
                "IEC 60309-2 Industrial connector three phase 64 amperes (usually red)",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_62196_T1",
              sublabel: 'IEC 62196 Type 1 "SAE J1772"',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_62196_T1_COMBO",
              sublabel: "Combo Type 1 based, DC",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_62196_T2",
              sublabel: 'IEC 62196 Type 2 "Mennekes"',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_62196_T2_COMBO",
              sublabel: "Combo Type 2 based, DC",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_62196_T3A",
              sublabel: "IEC 62196 Type 3A",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_62196_T3C",
              sublabel: 'IEC 62196 Type 3C "Scame"',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "PANTOGRAPH_BOTTOM_UP",
              sublabel:
                "On-board bottom-up-pantograph typically for bus charging",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "PANTOGRAPH_TOP_DOWN",
              sublabel:
                "Off-board top-down-pantograph typically for bus charging",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "TESLA_R",
              sublabel: 'Tesla connector "Roadster"-type (round, 4 pins)',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "TESLA_S",
              sublabel: 'Tesla connector "Model-S"-type (oval, 5 pins)',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "GB_T",
              sublabel: "The connector type is GB_T (Chinese standard), DC",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "CHAOJI",
              sublabel:
                "The ChaoJi connector. The new generation charging connector, harmonized between CHAdeMO and GB/T. DC.",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "NEMA_5_20",
              sublabel: "The connector type is NEMA 5-20, 3 pins",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "NEMA_6_30",
              sublabel: "The connector type is NEMA 6-30, 3 pins",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "NEMA_6_50",
              sublabel: "The connector type is NEMA 6-50, 3 pins",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "NEMA_10_30",
              sublabel: "The connector type is NEMA 10-30, 3 pins",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "NEMA_10_50",
              sublabel: "The connector type is NEMA 10-50, 3 pins",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "NEMA_14_30",
              sublabel:
                "The connector type is NEMA 14-30, 3 pins, rating of 30 A",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "NEMA_14_50",
              sublabel:
                "The connector type is NEMA 14-50, 3 pins, rating of 50 A",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
          ],
        },
        {
          label: "power",
          sublabel: "Usable electric power in kW",
          type: "Float",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "max_electric_power",
          sublabel: "Maximum electric power in kW",
          type: "Float",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "time",
          sublabel:
            "Time it takes to charge from 10 to 80% with a fast charger, shown in minutes",
          type: "Int",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "speed",
          sublabel: "Charging speed, default in kmph",
          type: "Float",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [
            {
              label: "unit",
              sublabel: null,
              type: "SpeedUnit",
              defaultValue: null,
              isEnum: true,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [
                {
                  label: "kilometers_per_hour",
                  sublabel: "Return the speed in kilometers per hour",
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
                {
                  label: "miles_per_hour",
                  sublabel: "Return the speed in miles per hour",
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
              ],
            },
          ],
          childList: [],
        },
      ],
    },
    {
      label: "adapters",
      sublabel: "Adapters available for the vehicle",
      type: "VehicleConnector",
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [
        {
          label: "standard",
          sublabel: "Connector type, known as connector standard in OCPI",
          type: "ConnectorType",
          isEnum: true,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [
            {
              label: "CHADEMO",
              sublabel: "The connector type is CHAdeMO, DC",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_A",
              sublabel:
                'Standard/domestic household, type "A", NEMA 1-15, 2 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_B",
              sublabel:
                'Standard/domestic household, type "B", NEMA 5-15, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_C",
              sublabel:
                'Standard/domestic household, type "C", CEE 7/17, 2 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_D",
              sublabel: 'Standard/domestic household, type "D", 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_E",
              sublabel: 'Standard/domestic household, type "E", CEE 7/5 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_F",
              sublabel:
                'Standard/domestic household, type "F", CEE 7/4, Schuko, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_G",
              sublabel:
                'Standard/domestic household, type "G", BS 1363, Commonwealth, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_H",
              sublabel: 'Standard/domestic household, type "H", SI-32, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_I",
              sublabel:
                'Standard/domestic household, type "I", AS 3112, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_J",
              sublabel:
                'Standard/domestic household, type "J", SEV 1011, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_K",
              sublabel:
                'Standard/domestic household, type "K", DS 60884-2-D1, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_L",
              sublabel:
                'Standard/domestic household, type "L", CEI 23-16-VII, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_M",
              sublabel: 'Standard/Domestic household, type "M", BS 546, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_N",
              sublabel:
                'Standard/Domestic household, type "N", NBR 14136, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "DOMESTIC_O",
              sublabel:
                'Standard/Domestic household, type "O", TIS 166-2549, 3 pins',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_60309_2_single_16",
              sublabel:
                "IEC 60309-2 Industrial connector single phase 16 amperes (usually blue)",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_60309_2_three_16",
              sublabel:
                "IEC 60309-2 Industrial connector three phase 16 amperes (usually red)",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_60309_2_three_32",
              sublabel:
                "IEC 60309-2 Industrial connector three phase 32 amperes (usually red)",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_60309_2_three_64",
              sublabel:
                "IEC 60309-2 Industrial connector three phase 64 amperes (usually red)",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_62196_T1",
              sublabel: 'IEC 62196 Type 1 "SAE J1772"',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_62196_T1_COMBO",
              sublabel: "Combo Type 1 based, DC",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_62196_T2",
              sublabel: 'IEC 62196 Type 2 "Mennekes"',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_62196_T2_COMBO",
              sublabel: "Combo Type 2 based, DC",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_62196_T3A",
              sublabel: "IEC 62196 Type 3A",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "IEC_62196_T3C",
              sublabel: 'IEC 62196 Type 3C "Scame"',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "PANTOGRAPH_BOTTOM_UP",
              sublabel:
                "On-board bottom-up-pantograph typically for bus charging",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "PANTOGRAPH_TOP_DOWN",
              sublabel:
                "Off-board top-down-pantograph typically for bus charging",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "TESLA_R",
              sublabel: 'Tesla connector "Roadster"-type (round, 4 pins)',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "TESLA_S",
              sublabel: 'Tesla connector "Model-S"-type (oval, 5 pins)',
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "GB_T",
              sublabel: "The connector type is GB_T (Chinese standard), DC",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "CHAOJI",
              sublabel:
                "The ChaoJi connector. The new generation charging connector, harmonized between CHAdeMO and GB/T. DC.",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "NEMA_5_20",
              sublabel: "The connector type is NEMA 5-20, 3 pins",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "NEMA_6_30",
              sublabel: "The connector type is NEMA 6-30, 3 pins",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "NEMA_6_50",
              sublabel: "The connector type is NEMA 6-50, 3 pins",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "NEMA_10_30",
              sublabel: "The connector type is NEMA 10-30, 3 pins",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "NEMA_10_50",
              sublabel: "The connector type is NEMA 10-50, 3 pins",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "NEMA_14_30",
              sublabel:
                "The connector type is NEMA 14-30, 3 pins, rating of 30 A",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "NEMA_14_50",
              sublabel:
                "The connector type is NEMA 14-50, 3 pins, rating of 50 A",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
          ],
        },
        {
          label: "power",
          sublabel: "Usable electric power in kW",
          type: "Float",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "max_electric_power",
          sublabel: "Maximum electric power in kW",
          type: "Float",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "time",
          sublabel:
            "Time it takes to charge from 10 to 80% with a fast charger, shown in minutes",
          type: "Int",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "speed",
          sublabel: "Charging speed, default in kmph",
          type: "Float",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [
            {
              label: "unit",
              sublabel: null,
              type: "SpeedUnit",
              defaultValue: null,
              isEnum: true,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [
                {
                  label: "kilometers_per_hour",
                  sublabel: "Return the speed in kilometers per hour",
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
                {
                  label: "miles_per_hour",
                  sublabel: "Return the speed in miles per hour",
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
              ],
            },
          ],
          childList: [],
        },
      ],
    },
    {
      label: "battery",
      sublabel: "Battery of the vehicle",
      type: "VehicleListBattery",
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [
        {
          label: "full_kwh",
          sublabel: "Full battery capacity in kWh",
          type: "Float",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
        {
          label: "usable_kwh",
          sublabel: "Usable battery capacity in kWh",
          type: "Float",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
      ],
    },
    {
      label: "body",
      sublabel: "Body of the vehicle",
      type: "VehicleListBody",
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [
        {
          label: "seats",
          sublabel: "Number of seats in a vehicle",
          type: "Int",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
      ],
    },
    {
      label: "availability",
      sublabel: "Availability of the vehicle",
      type: "VehicleListAvailability",
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [
        {
          label: "status",
          sublabel: "Availability of the vehicle",
          type: "VehicleAvailabilityStatus",
          isEnum: true,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [
            {
              label: "no_longer_available",
              sublabel: "Vehicle no longer for sale in any market / region",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "available",
              sublabel:
                "Vehicle currently for sale in at least one market / region",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "release_date_announced_preorderable",
              sublabel:
                "Vehicle expected in market from Date_From (estimated), pre-order open",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "release_date_announced",
              sublabel:
                "Vehicle expected in market from Date_From (estimated), pre-order unknown or not open",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "concept_vehicle_preorderable",
              sublabel:
                "Concept vehicle, nearing production and/or confirmed, pre-order open",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "concept_vehicle",
              sublabel:
                "Concept vehicle, nearing production and/or confirmed, pre-order unknown or not open",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "concept_vehicle_release_date_tba_preorderable",
              sublabel:
                "Concept vehicle, not close to production and/or unconfirmed, pre-order open",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "concept_vehicle_release_date_tba",
              sublabel:
                "Concept vehicle, not close to production and/or unconfirmed, pre-order unknown",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "uncertain",
              sublabel:
                "Status uncertain, introduction date and/or pricing unclear",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
          ],
        },
      ],
    },
    {
      label: "range",
      sublabel: "Range of the vehicle",
      type: "VehicleListRange",
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [
        {
          label: "chargetrip_range",
          sublabel:
            "Is an index value of what we consider to be the real-world range.\n(Comparable to Range_Real from EV Database.) It is essentially a normalized range to display in the front-end.",
          type: "ChargetripRange",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [
            {
              label: "worst",
              sublabel:
                "Worst conditions are based on -10°C and use of heating",
              type: "Float",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [
                {
                  label: "unit",
                  sublabel: null,
                  type: "DistanceUnit",
                  defaultValue: null,
                  isEnum: true,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [
                    {
                      label: "meter",
                      sublabel: "Return the distance in meters",
                      isEnum: false,
                      isDeprecated: false,
                      isRequired: false,
                      argumentList: [],
                      childList: [],
                    },
                    {
                      label: "foot",
                      sublabel: "Return the distance in feet",
                      isEnum: false,
                      isDeprecated: false,
                      isRequired: false,
                      argumentList: [],
                      childList: [],
                    },
                    {
                      label: "kilometer",
                      sublabel: "Return the distance in kilometers",
                      isEnum: false,
                      isDeprecated: false,
                      isRequired: false,
                      argumentList: [],
                      childList: [],
                    },
                    {
                      label: "mile",
                      sublabel: "Return the distance in miles",
                      isEnum: false,
                      isDeprecated: false,
                      isRequired: false,
                      argumentList: [],
                      childList: [],
                    },
                  ],
                },
              ],
              childList: [],
            },
            {
              label: "best",
              sublabel: "Best conditions are based on 23°C and no use of A/C",
              type: "Float",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [
                {
                  label: "unit",
                  sublabel: null,
                  type: "DistanceUnit",
                  defaultValue: null,
                  isEnum: true,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [
                    {
                      label: "meter",
                      sublabel: "Return the distance in meters",
                      isEnum: false,
                      isDeprecated: false,
                      isRequired: false,
                      argumentList: [],
                      childList: [],
                    },
                    {
                      label: "foot",
                      sublabel: "Return the distance in feet",
                      isEnum: false,
                      isDeprecated: false,
                      isRequired: false,
                      argumentList: [],
                      childList: [],
                    },
                    {
                      label: "kilometer",
                      sublabel: "Return the distance in kilometers",
                      isEnum: false,
                      isDeprecated: false,
                      isRequired: false,
                      argumentList: [],
                      childList: [],
                    },
                    {
                      label: "mile",
                      sublabel: "Return the distance in miles",
                      isEnum: false,
                      isDeprecated: false,
                      isRequired: false,
                      argumentList: [],
                      childList: [],
                    },
                  ],
                },
              ],
              childList: [],
            },
          ],
        },
      ],
    },
    {
      label: "media",
      sublabel: "Media of the vehicle",
      type: "VehicleListMedia",
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [
        {
          label: "image",
          sublabel: "Latest image of the vehicle",
          type: "VehicleImage",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [
            {
              label: "id",
              sublabel: "Image id",
              type: "ID",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "type",
              sublabel: "Image type",
              type: "VehicleImageType",
              isEnum: true,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [
                {
                  label: "provider",
                  sublabel: "Images provided by a Vehicle Datasource",
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
                {
                  label: "image",
                  sublabel: "Full-sized image at 1536x864 px",
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
                {
                  label: "image_thumbnail",
                  sublabel: "Thumbnail of a full-sized image at 131x72 px",
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
                {
                  label: "brand",
                  sublabel: "Full-sized brand (maker) logo at 768x432 px",
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
                {
                  label: "brand_thumbnail",
                  sublabel: "Thumbnail of a full-sized brand logo at 56x24 px",
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
              ],
            },
            {
              label: "url",
              sublabel: "Full path URL of a large image",
              type: "String",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "height",
              sublabel: "Height of a large image in pixels",
              type: "Int",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "width",
              sublabel: "Width of a large image in pixels",
              type: "Int",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "thumbnail_url",
              sublabel: "Full path URL of a thumbnail image",
              type: "String",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "thumbnail_height",
              sublabel: "Height of a thumbnail image in pixels",
              type: "Int",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "thumbnail_width",
              sublabel: "Width of a thumbnail image in pixels",
              type: "Int",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
          ],
        },
        {
          label: "brand",
          sublabel: "Latest maker logo of the vehicle",
          type: "VehicleImage",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [
            {
              label: "id",
              sublabel: "Image id",
              type: "ID",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "type",
              sublabel: "Image type",
              type: "VehicleImageType",
              isEnum: true,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [
                {
                  label: "provider",
                  sublabel: "Images provided by a Vehicle Datasource",
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
                {
                  label: "image",
                  sublabel: "Full-sized image at 1536x864 px",
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
                {
                  label: "image_thumbnail",
                  sublabel: "Thumbnail of a full-sized image at 131x72 px",
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
                {
                  label: "brand",
                  sublabel: "Full-sized brand (maker) logo at 768x432 px",
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
                {
                  label: "brand_thumbnail",
                  sublabel: "Thumbnail of a full-sized brand logo at 56x24 px",
                  isEnum: false,
                  isDeprecated: false,
                  isRequired: false,
                  argumentList: [],
                  childList: [],
                },
              ],
            },
            {
              label: "url",
              sublabel: "Full path URL of a large image",
              type: "String",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "height",
              sublabel: "Height of a large image in pixels",
              type: "Int",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "width",
              sublabel: "Width of a large image in pixels",
              type: "Int",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "thumbnail_url",
              sublabel: "Full path URL of a thumbnail image",
              type: "String",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "thumbnail_height",
              sublabel: "Height of a thumbnail image in pixels",
              type: "Int",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "thumbnail_width",
              sublabel: "Width of a thumbnail image in pixels",
              type: "Int",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
          ],
        },
        {
          label: "video",
          sublabel: "Latest video of the vehicle",
          type: "VehicleVideo",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [
            {
              label: "id",
              sublabel: "Video id",
              type: "ID",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
            {
              label: "url",
              sublabel: "Full path URL of a video",
              type: "String",
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
          ],
        },
      ],
    },
    {
      label: "routing",
      sublabel: "Routing of the vehicle",
      type: "VehicleListRouting",
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [
        {
          label: "fast_charging_support",
          sublabel:
            "Vehicles that support fast charging have a minimum charging speed of 43 kWh",
          type: "Boolean",
          isEnum: false,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [],
        },
      ],
    },
    {
      label: "connect",
      sublabel: "Information about vehicle connectivity",
      type: "Connect",
      isEnum: false,
      isDeprecated: false,
      isRequired: false,
      argumentList: [],
      childList: [
        {
          label: "providers",
          sublabel:
            "List of connectivity providers to which a vehicle can connect",
          type: "ConnectProvider",
          isEnum: true,
          isDeprecated: false,
          isRequired: false,
          argumentList: [],
          childList: [
            {
              label: "Enode",
              sublabel: null,
              isEnum: false,
              isDeprecated: false,
              isRequired: false,
              argumentList: [],
              childList: [],
            },
          ],
        },
      ],
    },
  ],
};
