import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import CTSegmentBlock from "./../segment-block/SegmentBlock.vue";
import { CTIcon, IconName } from "./../icon";

describe("SegmentBlock", () => {
  it("renders an empty SegmentBlock", async () => {
    const wrapper = mount(CTSegmentBlock);

    expect(wrapper.text()).toBe("");
  });

  it("renders a label", async () => {
    const wrapper = mount(CTSegmentBlock, {
      propsData: {
        label: "Example",
      },
    });

    expect(wrapper.text()).toBe("Example");
  });

  it("renders an icon", async () => {
    const wrapper = mount(CTSegmentBlock, {
      propsData: {
        icon: IconName.MD_LAYOUTS_GRAPH_BARS,
      },
    });

    expect(wrapper.findComponent(CTIcon)).toBeTruthy();
  });

  it("has a disabled state", async () => {
    const wrapper = mount(CTSegmentBlock, {
      propsData: {
        isDisabled: true,
      },
    });

    expect(wrapper.classes()).toContain("is-disabled");
  });

  it("has an active state", async () => {
    const wrapper = mount(CTSegmentBlock, {
      propsData: {
        isActive: true,
      },
    });

    expect(wrapper.classes()).toContain("is-active");
  });

  it("has a hover state", async () => {
    const wrapper = mount(CTSegmentBlock, {
      propsData: {
        label: "Example",
      },
    });

    await wrapper.trigger("mouseenter");
    expect(wrapper.classes()).toContain("has-hover");

    await wrapper.trigger("mouseleave");
    expect(wrapper.classes()).not.toContain("has-hover");
  });

  it("emits click", async () => {
    const wrapper = mount(CTSegmentBlock, {
      propsData: {
        label: "Example",
      },
    });

    await wrapper.trigger("click");

    expect(wrapper.emitted("click")?.[0]).toBeTruthy();
  });
});
