import { expect, describe, it } from "vitest";
import { mount } from "@vue/test-utils";
import { CTSegmentButtonBlock } from "../segment-button";
import { IconName } from "../icon";

describe("SegmentButtonBlock", () => {
  it("renders icon", async () => {
    const wrapper = mount(CTSegmentButtonBlock);

    expect(wrapper.findComponent({ ref: "iconRef" }).exists()).toStrictEqual(
      false,
    );

    await wrapper.setProps({ icon: IconName.MD_CONTROLS_LOADING_CIRCLE });

    expect(
      wrapper.findComponent({ ref: "iconRef" }).props("name"),
    ).toStrictEqual(IconName.MD_CONTROLS_LOADING_CIRCLE);
  });

  it("renders label", async () => {
    const label = "Label";

    const wrapper = mount(CTSegmentButtonBlock);

    expect(wrapper.find({ ref: "labelRef" }).exists()).toStrictEqual(false);

    await wrapper.setProps({ label });

    expect(wrapper.find({ ref: "labelRef" }).text()).toStrictEqual(label);
  });

  it("emits click", async () => {
    const wrapper = mount(CTSegmentButtonBlock);

    await wrapper.trigger("click");
    expect(wrapper.emitted("click")).toBeTruthy();
  });

  it("can be disabled", async () => {
    const wrapper = mount(CTSegmentButtonBlock, {
      props: { isDisabled: true },
    });

    await wrapper.trigger("click");
    expect(wrapper.emitted("click")).toBeFalsy();
  });
});
