import { expect, describe, it } from "vitest";
import { mount } from "@vue/test-utils";
import {
  CTSegmentButton,
  CTSegmentButtonBlock,
  SegmentButtonType,
  SegmentButtonVariant,
} from "../segment-button";
import { stub as props } from "./stub";
const { itemList } = props;
describe("SegmentButton", () => {
  it("renders type class", async () => {
    const wrapper = mount(CTSegmentButton, { props });

    expect(wrapper.classes(`type-${SegmentButtonType.PRIMARY}`)).toStrictEqual(
      true,
    );

    await wrapper.setProps({ type: SegmentButtonType.SECONDARY });

    expect(
      wrapper.classes(`type-${SegmentButtonType.SECONDARY}`),
    ).toStrictEqual(true);
  });

  it("renders variant class", async () => {
    const wrapper = mount(CTSegmentButton, { props });

    expect(
      wrapper.classes(`variant-${SegmentButtonVariant.DEFAULT}`),
    ).toStrictEqual(true);

    await wrapper.setProps({ variant: SegmentButtonVariant.ELEVATED });

    expect(
      wrapper.classes(`variant-${SegmentButtonVariant.ELEVATED}`),
    ).toStrictEqual(true);
  });

  it("renders item list", async () => {
    const wrapper = mount(CTSegmentButton, {
      props: { ...props, itemList: [] },
    });

    expect(
      wrapper.findAllComponents(CTSegmentButtonBlock).length,
    ).toStrictEqual(0);

    await wrapper.setProps({ itemList });

    wrapper
      .findAllComponents(CTSegmentButtonBlock)
      .forEach((component, key) => {
        expect(component.props()).toEqual(itemList![key]);
      });
  });
});
