import { SegmentButtonType, SegmentButtonVariant } from "./constants";
import { stub } from "./stub";
import type { Meta, StoryObj } from "@storybook/vue3";
import { CTSegmentButton, CTSegmentButtonBlock } from "./index";
import type { SegmentButtonProps } from "./index";
import { IconName } from "../icon";
import { ref } from "vue";

const meta: Meta<typeof CTSegmentButton> = {
  title: "Button/SegmentButton",
  component: CTSegmentButton,
  argTypes: {
    type: { control: "select", options: Object.values(SegmentButtonType) },
    variant: {
      control: "select",
      options: Object.values(SegmentButtonVariant),
    },
  },
};

export const Label: StoryObj<typeof CTSegmentButton> = {
  args: {
    ...stub,
  },
  render: (args: SegmentButtonProps) => ({
    setup() {
      const itemList = ref([
        { label: "Button 1" },
        { label: "Button 2" },
        { label: "Button 3" },
      ]);
      return { args, IconName, itemList };
    },
    components: { CTSegmentButton, CTSegmentButtonBlock },
    template: `<div class="flex items-start">
      <CTSegmentButton v-bind="args" :item-list="itemList"/>
    </div>`,
  }),
};

export const Icon: StoryObj<typeof CTSegmentButton> = {
  args: {
    ...stub,
  },
  render: (args: SegmentButtonProps) => ({
    setup() {
      const itemList = ref([
        { icon: IconName.MD_NAVIGATION_ARROW_LEFT },
        { icon: IconName.MD_NAVIGATION_ARROW_LEFT },
        { icon: IconName.MD_NAVIGATION_ARROW_LEFT },
      ]);
      return { args, itemList };
    },
    components: { CTSegmentButton, CTSegmentButtonBlock },
    template: `<div class="flex items-start">
      <CTSegmentButton v-bind="args" :item-list="itemList"/>
    </div>`,
  }),
};

export default meta;
