import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import { CTMultiSelect } from "./index";
import { defaultOptionList, stub } from "./stub";
import { SelectType } from "./constants";
import { CTCheckbox } from "../checkbox";
import { CTListItem } from "../list-item";

const props = stub;
const { id, label } = props;

describe("MultiSelect", () => {
  it("passes props", async () => {
    const wrapper = mount(CTMultiSelect, {
      props: { ...props, type: SelectType.FILTER, modelValue: [] },
    });

    expect(
      wrapper.findComponent({ ref: "baseSelectRef" }).props(),
    ).toStrictEqual(
      expect.objectContaining({
        id,
        label,
      }),
    );
  });

  it("emits model value", async () => {
    const wrapper = mount(CTMultiSelect, {
      props: { ...props, type: SelectType.FILTER, modelValue: [] },
    });

    const firstListItem = wrapper.findAllComponents(CTListItem)[0];
    await firstListItem?.vm.$emit("click");

    expect(wrapper.emitted("update:modelValue")?.[0]).toStrictEqual([
      [defaultOptionList[0].value],
    ]);

    await wrapper.setProps({ modelValue: [defaultOptionList[0].value] });

    // skip index 1 because it's disabled.
    const nextListItem = wrapper.findAllComponents(CTListItem)[2];
    nextListItem?.vm.$emit("click");

    expect(wrapper.emitted("update:modelValue")?.[1]).toStrictEqual([
      // skip 1 because 1 is a divider
      [defaultOptionList[0].value, defaultOptionList[2].value],
    ]);
  });

  it("can activate checkbox", async () => {
    const wrapper = mount(CTMultiSelect, {
      props: { ...props, type: SelectType.FILTER, modelValue: [] },
    });

    const firstCheckbox = wrapper.findAllComponents(CTCheckbox)[0];

    expect(firstCheckbox.props("modelValue")).toStrictEqual(false);

    await wrapper.setProps({ modelValue: [defaultOptionList[0].value] });

    expect(firstCheckbox.props("modelValue")).toStrictEqual(true);
  });

  it("sets value slot", async () => {
    const wrapper = mount(CTMultiSelect, {
      props: { ...props, modelValue: [] },
    });

    expect(wrapper.find({ ref: "valueRef" }).text()).toStrictEqual(label);

    await wrapper.setProps({ modelValue: [defaultOptionList[0].value] });

    expect(wrapper.find({ ref: "valueRef" }).text()).toStrictEqual(
      defaultOptionList[0].label,
    );

    await wrapper.setProps({
      modelValue: [defaultOptionList[0].value, defaultOptionList[1].value],
    });

    expect(wrapper.find({ ref: "valueRef" }).text()).toStrictEqual(
      `${defaultOptionList[0].label}, +1`,
    );

    await wrapper.setProps({
      modelValue: ["test"],
    });

    expect(wrapper.find({ ref: "valueRef" }).text()).toStrictEqual(`test`);
  });
});
