import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import { CTSingleSelect } from "./index";
import { defaultOptionList, stub } from "./stub";
import { SelectType } from "./constants";
import { CTListItem } from "../list-item";

const props = stub;
const { id, label } = props;
describe("CTSingleSelect", () => {
  it("passes props", async () => {
    const wrapper = mount(CTSingleSelect, {
      props: { ...props, type: SelectType.FILTER, modelValue: "" },
    });

    expect(
      wrapper.findComponent({ ref: "baseSelectRef" }).props(),
    ).toStrictEqual(
      expect.objectContaining({
        id,
        label,
      }),
    );
  });

  it("emits model value", async () => {
    const wrapper = mount(CTSingleSelect, {
      props: { ...props, type: SelectType.FILTER, modelValue: "" },
    });

    const firstListItem = wrapper.findAllComponents(CTListItem)[0];

    await firstListItem?.vm.$emit("click");

    expect(wrapper.emitted("update:modelValue")?.[0]).toStrictEqual([
      defaultOptionList[0].value,
    ]);

    await wrapper.setProps({ modelValue: defaultOptionList[0].value });
    const nextListItem = wrapper.findAllComponents(CTListItem)[2];
    await nextListItem?.vm.$emit("click");

    expect(wrapper.emitted("update:modelValue")?.[1]).toStrictEqual([
      // skip 1 because 1 is a divider
      defaultOptionList[2].value,
    ]);
  });

  it("can activate radio", async () => {
    const wrapper = mount(CTSingleSelect, {
      props: { ...props, type: SelectType.FILTER, modelValue: "" },
    });

    expect(
      wrapper.findComponent({ ref: "radioRef" }).props("modelValue"),
    ).toStrictEqual("");

    await wrapper.setProps({ modelValue: defaultOptionList[0].value });

    expect(
      wrapper.findComponent({ ref: "radioRef" }).props("modelValue"),
    ).toStrictEqual(defaultOptionList[0].value);
  });

  it("can show circle done icon", async () => {
    const wrapper = mount(CTSingleSelect, {
      props: { ...props, type: SelectType.DEFAULT, modelValue: "" },
    });

    expect(
      wrapper.findComponent({ ref: "circleDoneIconRef" }).exists(),
    ).toStrictEqual(false);

    await wrapper.setProps({ modelValue: defaultOptionList[0].value });

    expect(
      wrapper.findComponent({ ref: "circleDoneIconRef" }).exists(),
    ).toStrictEqual(true);
  });
});
