import type { Meta, StoryObj } from "@storybook/vue3";
import { CTMultiSelect, CTSingleSelect, CTBaseSelect } from "../select";
import { reactive } from "vue";
import { CTButton } from "../button";
import { ButtonType } from "../base-button";
import { required } from "@vuelidate/validators";
import useVuelidate from "@vuelidate/core";
import { stub } from "./stub";
import type { MultiSelectProps, SingleSelectProps } from "./types";
import { SelectType } from "./constants";
import { FormControlSize } from "../form-control/constants";

const meta: Meta<typeof CTBaseSelect> = {
  title: "form/Select",
  argTypes: {
    type: { control: "select", options: Object.values(SelectType) },
    size: { control: "select", options: Object.values(FormControlSize) },
  },
};

export default meta;

export const MultiSelect: StoryObj<typeof CTMultiSelect> = {
  args: {
    ...stub,
    isRounded: true,
    modelValue: [""],
    type: SelectType.FILTER,
  },
  // @ts-ignore:next-line
  render: (args: MultiSelectProps<string>) => ({
    components: { CTMultiSelect, CTButton },
    setup() {
      const state = reactive<{ modelValue: string[] }>({ modelValue: [] });
      const rules = {
        modelValue: {
          required,
        },
      };
      const v$ = useVuelidate(rules, state);

      return { args, v$, state, ButtonType };
    },
    template: `
    <div class="flex w-full gap-4 items-start h-[500vh] flex-col">
      {{state.modelValue}}
      <CTMultiSelect v-bind="args" v-model="state.modelValue" :validation="v$.modelValue" class="w-max" :query="''"/>
<!--      <CTButton :type="ButtonType.PRIMARY" @click="v$.$touch()">Submit</CTButton>-->
    </div>`,
  }),
};

export const SingleSelect: StoryObj<typeof CTSingleSelect> = {
  args: {
    ...stub,
    isRounded: true,
    modelValue: "",
    type: SelectType.FILTER,
  },
  // @ts-ignore:next-line
  render: (args: SingleSelectProps<string>) => ({
    components: { CTSingleSelect, CTButton },
    setup() {
      const state = reactive<{ modelValue: string }>({ modelValue: "" });
      const rules = {
        modelValue: {
          required,
        },
      };
      const v$ = useVuelidate(rules, state);

      return { args, v$, state, ButtonType };
    },
    template: `
    <div class="flex w-full gap-4 items-start h-[500vh] flex-col">
      {{state.modelValue}}
      <CTSingleSelect v-bind="args" v-model="state.modelValue" :validation="v$.modelValue" class="w-max"/>
<!--      <CTButton :type="ButtonType.PRIMARY" @click="v$.$touch()">Submit</CTButton>-->
    </div>`,
  }),
};
