import type { FormControlProps } from "../form-control";
import { SelectOptionType, SelectType } from "../select";
import type { Validation } from "@vuelidate/core";

export interface BaseSelectEmits {
  (name: "update:isActive", value: boolean): void;
  (name: "update:query", value: string): void;
  (name: "input", value: number): void;
  (name: "clear"): void;
}

export interface SelectOptionHeader {
  label: string;
  type: SelectOptionType.HEADER;
}

export interface SelectOptionDefault<T> {
  label: string;
  value: T;
  isDisabled?: boolean;
  sublabel?: string;
  type?: SelectOptionType;
}

export type SelectOption<T> = SelectOptionDefault<T> | SelectOptionHeader;

export interface BaseSelectProps<T> extends FormControlProps {
  modelValue: T | T[];
  optionList: SelectOption<T>[];
  validation?: Validation;
  hasFilter?: boolean;
  isRounded?: boolean;
  type?: SelectType;
  query?: string;
  isActive?: boolean;
}

export interface SingleSelectEmits<T> {
  (name: "update:modelValue", value: T | undefined): void;
  (name: "update:query", value: string): void;
}

export interface SingleSelectProps<T> extends BaseSelectProps<T> {
  modelValue: T;
}

export interface MultiSelectEmits<T> {
  (name: "update:modelValue", value: T[]): void;
  (name: "update:query", value: string): void;
}

export interface MultiSelectProps<T> extends BaseSelectProps<T> {
  modelValue: T[];
}

export interface SelectListItemProps<T> extends SelectOptionDefault<T> {
  index: number;
}

export interface BaseSelectSlots<T> {
  prefix(): void;
  value(): void;
  suffix(): void;
  dropdownStart(): void;
  listItemPrefix(props: SelectListItemProps<T>): void;
  listItemSuffix(props: SelectListItemProps<T>): void;
}

export interface SingleSelectSlots {
  dropdownStart(): void;
}

export interface MultiSelectSlots<T> {
  dropdownStart(): void;
  listItemPrefix(props: SelectListItemProps<T>): void;
  listItemSuffix(props: SelectListItemProps<T>): void;
}
