import { CTSwitch, SwitchColor } from "../switch";
import type { SwitchProps } from "../switch";
import { stub } from "./stub";
import { reactive, ref } from "vue";
import { sameAs } from "@vuelidate/validators";
import useVuelidate from "@vuelidate/core";
import { CTButton } from "../button";
import { ButtonType } from "../base-button";
import type { Meta, StoryObj } from "@storybook/vue3";
import { FormControlSize } from "../form-control";

const meta: Meta<typeof CTSwitch> = {
  title: "form/Switch",
  component: CTSwitch,
  argTypes: {
    id: { control: "text" },
    isDisabled: { control: "boolean" },
    isBoxed: { control: "boolean" },
    size: { control: "select", options: Object.values(FormControlSize) },
    color: { control: "select", options: Object.values(SwitchColor) },
  },
};

const template: StoryObj<typeof CTSwitch> = {
  args: {
    ...stub,
  },
  render: (args: SwitchProps) => ({
    components: { CTSwitch, CTButton },
    setup() {
      const state = reactive({ terms: false });
      const rules = {
        terms: {
          sameAs: sameAs(ref(true)),
        },
      };
      const v$ = useVuelidate(rules, state);

      return { args, state, v$, ButtonType };
    },
    template: `<div class="flex flex-col gap-y-4 items-start">
      <CTSwitch v-bind="args" v-model="state.terms" :validation="v$"/>
      <CTButton :type="ButtonType.PRIMARY" @click="v$.$touch()">Submit</CTButton>
    </div>`,
  }),
};

export const Normal = {
  ...template,
};

export const Boxed = {
  ...template,
  args: {
    ...template.args,
    isBoxed: true,
  },
};

export default meta;
