import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import { CTSwitch } from "./index";
import { stub } from "./stub";

const props = { ...stub };

describe("Switch", () => {
  it("emits model value", async () => {
    const wrapper = mount(CTSwitch, {
      props,
    });

    await wrapper.trigger("click");
    expect(wrapper.emitted("update:modelValue")?.[0]).toEqual([true]);
    await wrapper.find({ ref: "inputRef" }).trigger("change");
    expect(wrapper.emitted("update:modelValue")?.[1]).toEqual([true]);
  });

  it("can be boxed", async () => {
    const wrapper = mount(CTSwitch, {
      props: { ...props, isBoxed: false },
    });

    expect(wrapper.classes("is-boxed")).toBe(false);
    await wrapper.setProps({ isBoxed: true });
    expect(wrapper.classes("is-boxed")).toBe(true);
  });
});
