import { describe } from "vitest";
import { it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import { CTBodyCell } from "./index";
import { cellStub as props } from "./stub";

const { label, sublabel } = props;
describe("CTBodyCell", () => {
  it("renders label", async () => {
    const wrapper = mount(CTBodyCell);

    expect(wrapper.find({ ref: "labelRef" }).exists()).toStrictEqual(false);

    await wrapper.setProps({ label });

    expect(wrapper.find({ ref: "labelRef" }).exists()).toStrictEqual(true);
    expect(wrapper.find({ ref: "labelRef" }).text()).toStrictEqual(label);
  });

  it("renders sublabel", async () => {
    const wrapper = mount(CTBodyCell);

    expect(wrapper.find({ ref: "sublabelRef" }).exists()).toStrictEqual(false);

    await wrapper.setProps({ sublabel });

    expect(wrapper.find({ ref: "sublabelRef" }).exists()).toStrictEqual(true);
    expect(wrapper.find({ ref: "sublabelRef" }).text()).toStrictEqual(sublabel);
  });

  it("can be mono", async () => {
    const wrapper = mount(CTBodyCell, { props: { sublabel, label } });

    expect(
      wrapper.find({ ref: "sublabelRef" }).classes("font-mono"),
    ).toStrictEqual(false);
    expect(
      wrapper.find({ ref: "labelRef" }).classes("font-mono"),
    ).toStrictEqual(false);

    await wrapper.setProps({ isSublabelMono: true });
    await wrapper.setProps({ isLabelMono: true });

    expect(
      wrapper.find({ ref: "sublabelRef" }).classes("font-mono"),
    ).toStrictEqual(true);
    expect(
      wrapper.find({ ref: "labelRef" }).classes("font-mono"),
    ).toStrictEqual(true);
  });

  it("can right aligned", async () => {
    const wrapper = mount(CTBodyCell);

    expect(wrapper.classes("is-aligned-right")).toStrictEqual(false);

    await wrapper.setProps({ alignRight: true });

    expect(wrapper.classes("is-aligned-right")).toStrictEqual(true);
  });
});
