import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import CTTag from "./Tag.vue";
import { stub } from "./stub";
import { CTIcon, IconName } from "../icon";

const props = { ...stub };
const { label, variant, size } = props;

describe("Tag", () => {
  it("renders label", async () => {
    const wrapper = mount(CTTag, { props });

    expect(wrapper.text()).toBe(label);
  });

  it("renders slot", async () => {
    const wrapper = mount(CTTag, {
      props: { ...props, label: undefined },

      slots: { default: label! },
    });

    expect(wrapper.text()).toBe(label);
  });

  it("renders icon left", async () => {
    const wrapper = mount(CTTag, {
      props: { ...props, iconLeft: undefined, iconRight: undefined },
    });
    expect(wrapper.findComponent(CTIcon).exists()).toBe(false);

    await wrapper.setProps({ iconLeft: IconName.MD_NAVIGATION_ARROW_LEFT });
    expect(wrapper.findComponent(CTIcon).exists()).toBe(true);
  });

  it("renders icon right", async () => {
    const wrapper = mount(CTTag, {
      props: { ...props, iconLeft: undefined, iconRight: undefined },
    });
    expect(wrapper.findComponent(CTIcon).exists()).toBe(false);

    await wrapper.setProps({ iconRight: IconName.MD_NAVIGATION_ARROW_RIGHT });
    expect(wrapper.findComponent(CTIcon).exists()).toBe(true);
  });

  it("has color class", async () => {
    const wrapper = mount(CTTag, { props });

    expect(wrapper.classes()).toContain(`variant-${variant}`);
  });

  it("has size class", async () => {
    const wrapper = mount(CTTag, { props });

    expect(wrapper.classes()).toContain(`size-${size}`);
  });
});
