import { CTTheme } from "../theme";
import type { ThemeProps } from "../theme";
import { computed } from "vue";
import { ThemeType } from "../theme";
import type { Meta, StoryObj } from "@storybook/vue3";

const meta: Meta<typeof CTTheme> = {
  title: "Theme",
  component: CTTheme,
  argTypes: {
    type: { control: "select", options: Object.values(ThemeType) },
  },
};

export const Normal: StoryObj<typeof CTTheme> = {
  args: {
    type: ThemeType.WEB,
  },
  render: (args: ThemeProps) => ({
    components: { CTTheme },
    setup() {
      const isWeb = computed(() => args.type === ThemeType.WEB);
      const isApp = computed(() => args.type === ThemeType.APP);

      return { args, isWeb, isApp };
    },
    template: `
    <div class="flex flex-col gap-y-4">
      <h1>
        Heading 1
      </h1>
      <h2>
        Heading 2
      </h2>
      <h3>
        Heading 3
      </h3>
      <h4>
        Heading 4
      </h4>
      <h5>
        Heading 5
      </h5>
      <h6>
        Heading 6
      </h6>
      <p>
        Body large  
      </p>
      <p>
        Body normal
      </p>
      <p>
        <strong>
          Body normal
        </strong>
      </p>
      <template v-if="isApp">
        <p class="text-sm">
          Body small
        </p>
        <p class="text-xs">
          Body Micro
        </p>
      </template>
      <template v-if="isWeb">
        <p class="text-lg">
          Body small
        </p>
        <p class="text-md">
          Body Micro
        </p>
      </template>
    </div>
  `,
  }),
};

export default meta;
