import { describe, it, expect } from "vitest";
import { mount } from "@vue/test-utils";
import { CTTooltip } from "../tooltip";
import { stub } from "./stub";
import { TooltipDirection } from "./constants";

const props = { ...stub };
const { title, description } = props;

describe("Tooltip", () => {
  it("renders title", async () => {
    const wrapper = mount(CTTooltip);

    expect(wrapper.find({ ref: "titleRef" }).exists()).toBe(false);
    await wrapper.setProps({ title });
    expect(wrapper.find({ ref: "titleRef" }).text()).toBe(title);
  });

  it("renders description", async () => {
    const wrapper = mount(CTTooltip);

    expect(wrapper.find({ ref: "descriptionRef" }).exists()).toBe(false);
    await wrapper.setProps({ description });
    expect(wrapper.find({ ref: "descriptionRef" }).text()).toBe(description);
    expect(wrapper.find({ ref: "descriptionRef" }).exists()).toBe(true);
  });

  it("can show pointer", async () => {
    const wrapper = mount(CTTooltip);

    expect(wrapper.find({ ref: "pointerRef" }).exists()).toBe(false);
    await wrapper.setProps({ showPointer: true });
    expect(wrapper.find({ ref: "pointerRef" }).exists()).toBe(true);
  });

  it("renders direction", async () => {
    const wrapper = mount(CTTooltip, { props, attachTo: document.body });

    expect(
      wrapper
        .find({ ref: "elRef" })
        .classes(`direction-${TooltipDirection.BOTTOM}`),
    ).toBe(true);

    await wrapper.setProps({ direction: TooltipDirection.RIGHT });

    expect(
      wrapper
        .find({ ref: "elRef" })
        .classes(`direction-${TooltipDirection.RIGHT}`),
    ).toBe(true);
  });
});
