import type { Directive, DirectiveBinding } from "vue";
import { useRafFn } from "@vueuse/core";

const state = new WeakMap();

const init = (el: HTMLElement, binding: DirectiveBinding): void => {
  // eslint-disable-next-line prefer-const
  let _pause: undefined | (() => void);
  const { src, callback, isImage, isPreload } = binding.value || {};
  const setAttribute = (): void => el.setAttribute("src", src);

  const { pause } = useRafFn(() => {
    if (
      isPreload ||
      el.getBoundingClientRect().top - window.innerHeight * 1.5 < 0
    ) {
      _pause?.();
      callback?.();

      if (!src) return;

      if (isImage) {
        const img = new Image();

        img.crossOrigin = "Anonymous";
        img.onload = setAttribute;
        img.onerror = setAttribute;

        img.src = src;
      } else {
        setAttribute();
      }
    }
  });

  _pause = pause;

  state.set(el, { pause });
};
export const vLazyLoad: Directive = {
  mounted: init,
  updated: init,
  beforeUpdate(el) {
    const { pause } = state.get(el) || {};

    pause?.();
  },
  beforeUnmount(el) {
    const { pause } = state.get(el) || {};
    pause?.();
  },
};
