import { defineStore } from "pinia";
import { ThemeColor } from "../components/theme/constants";
import { computed, ref } from "vue";
import Cookies from "cookiejs";
import { usePreferredColorScheme, useWindowSize } from "@vueuse/core";

const preferredColor = usePreferredColorScheme();
export const useRootStore = defineStore("root", () => {
  const token = ref<string | null | undefined>(null);
  const workspace = ref();
  const name = ref();
  const { width: windowWidth } = useWindowSize();

  const isMobile = computed(() => {
    return windowWidth.value <= 1024;
  });
  const setToken = (newToken: string | null): void => {
    token.value = newToken;
  };

  const checkForUserInfoCookies = (): void => {
    workspace.value = Cookies.get("workspace");
    name.value = Cookies.get("name");
  };

  const themeColor = ref(ThemeColor.SYSTEM);
  const isLoggedIn = computed(() => Boolean(token.value));

  const normalizedThemeColor = computed<ThemeColor>(() => {
    if (themeColor.value === ThemeColor.SYSTEM) {
      return preferredColor.value === "light"
        ? ThemeColor.LIGHT
        : ThemeColor.DARK;
    } else {
      return themeColor.value;
    }
  });

  function setThemeColor(color: ThemeColor): void {
    themeColor.value = color;
    Cookies.set("themeColor", color, { expires: 365, path: "/" });
  }

  return {
    isMobile,
    checkForUserInfoCookies,
    normalizedThemeColor,
    workspace,
    name,
    setToken,
    setThemeColor,
    isLoggedIn,
    themeColor,
  };
});
