import {
  addDays,
  endOfDay,
  endOfYear,
  isSameDay,
  startOfDay,
  startOfYear,
  subDays,
  subYears,
} from "date-fns";
import { CalendarDateRange } from "../components";
import type { PresetDateItem } from "../components";

export const stringToDate = (date: string): Date => {
  return new Date(date.split("-").reverse().join("-"));
};

export const getOptionIndexByRange = (
  list: PresetDateItem[],
  range: [Date, Date],
): number => {
  const index = list.findIndex((option) => {
    const startDate = option.range?.[0];
    const endDate = option.range?.[1];

    return (
      startDate &&
      endDate &&
      isSameDay(startDate, range[0]) &&
      isSameDay(endDate, range[1])
    );
  });

  return index < 0 ? list.findIndex((item) => item.isCustom) : index;
};

export const getOptionByRange = (
  list: PresetDateItem[],
  range: [Date, Date],
): PresetDateItem => {
  const index = getOptionIndexByRange(list, range);

  return list[index];
};
const today = new Date();
const todayStart = startOfDay(new Date());
const yesterday = endOfDay(addDays(new Date(), -1));
const startOfYearDate = startOfYear(today);

export const getDateRange = (range: CalendarDateRange): [Date, Date] => {
  switch (range) {
    case CalendarDateRange.LAST_7:
      return [subDays(todayStart, 7), yesterday];
    case CalendarDateRange.LAST_30:
      return [subDays(todayStart, 30), yesterday];
    case CalendarDateRange.LAST_90:
      return [subDays(todayStart, 90), yesterday];
    case CalendarDateRange.LAST_180:
      return [subDays(todayStart, 180), yesterday];
    case CalendarDateRange.LAST_YEAR:
      const lastYear = subYears(todayStart, 1);

      return [startOfYear(lastYear), endOfYear(lastYear)];
    case CalendarDateRange.CURRENT_YEAR:
      return [startOfYearDate, today];

    default:
      return [todayStart, yesterday];
  }
};
