import { createI18n, useI18n as _useI18n } from "vue-i18n";
import type { UseI18nOptions } from "vue-i18n";

export enum NumberFormat {
  CURRENCY = "currency",
  PERCENT = "percent",
  PERCENT_DECIMAL = "percent-decimal",
  DECIMAL = "decimal",
}

export enum DateFormat {
  MONTH_YEAR = "monthYear",
  DAY_MONTH_YEAR = "dayMonthYear",
  SHORT_TIMESTAMP = "short-timestamp",
  LONG_TIMESTAMP = "long-timestamp",
}

export const datetimeFormats: Record<
  string,
  Record<string, Intl.DateTimeFormatOptions>
> = {
  en: {
    [DateFormat.MONTH_YEAR]: {
      year: "numeric",
      month: "long",
    },
    [DateFormat.DAY_MONTH_YEAR]: {
      year: "numeric",
      month: "long",
      day: "numeric",
    },
    [DateFormat.SHORT_TIMESTAMP]: {
      hour: "numeric",
      minute: "numeric",
      hour12: false,
    },
    [DateFormat.LONG_TIMESTAMP]: {
      hour: "numeric",
      minute: "numeric",
      second: "numeric",
    },
  },
};

export const numberFormats: Record<
  string,
  Record<string, Intl.NumberFormatOptions>
> = {
  en: {
    [NumberFormat.CURRENCY]: {
      style: "currency",
      currency: "EUR",
      notation: "standard",
    },
    [NumberFormat.DECIMAL]: {
      style: "decimal",
      minimumFractionDigits: 0,
      maximumFractionDigits: 2,
    },
    [NumberFormat.PERCENT]: {
      style: "percent",
      useGrouping: false,
    },
    [NumberFormat.PERCENT_DECIMAL]: {
      style: "percent",
      minimumFractionDigits: 2,
      maximumFractionDigits: 2,
      useGrouping: false,
    },
  },
};

export const i18n = createI18n({
  locale: "en",
  messages: {},
  legacy: false,
  datetimeFormats,
  numberFormats,
});

export const useI18n = (
  options: UseI18nOptions,
): ReturnType<typeof _useI18n> => {
  // eslint-disable-next-line @typescript-eslint/ban-ts-comment
  // @ts-ignore
  return _useI18n({
    ...options,
    datetimeFormats,
    numberFormats,
  });
};
