import type { SubItem } from "../components/menu-dropdown";
import { IconName } from "../components/icon";
import type { MaybeRef } from "@vueuse/core";
import { resolveUnref } from "@vueuse/core";

export const useProfileMenuItems = ({
  isDashboard,
}: {
  isDashboard?: MaybeRef<boolean | undefined>;
}): Array<SubItem> => {
  const _isDashboard = Boolean(resolveUnref(isDashboard));

  const helpCenter = {
    label: "Help center",
    href: "https://help.chargetrip.com",
    icon: IconName.MD_PRODUCTS_HELP_CENTER,
  };

  if (_isDashboard) {
    return [
      helpCenter,
      {
        label: "Developer portal",
        href: "https://developers.chargetrip.com",
        icon: IconName.MD_CODE_CODE,
      },
      {
        label: "Edit profile",
        to: "/profile",
        icon: IconName.MD_CONTENT_CIRCLE_PERSON,
      },
    ];
  }

  return [
    helpCenter,
    {
      label: "Dashboard",
      href: "https://account.chargetrip.com",
      icon: IconName.MD_CONTENT_DASHBOARD,
    },
    {
      label: "Edit profile",
      href: "https://account.chargetrip.com/profile",
      icon: IconName.MD_CONTENT_CIRCLE_PERSON,
    },
  ];
};
