import type { Ref } from "vue";
import { ref, watch } from "vue";
import { refAutoReset } from "@vueuse/core";

export interface UseScrollInViewReturn {
  setScrollPosition: () => void;
  behaviour: Ref<ScrollBehavior>;
  isDisabled: Ref<boolean>;
}

export const useScrollInView = (
  itemList: Ref<HTMLElement[]>,
  container: Ref<HTMLElement | undefined>,
  index: Ref<number | null>,
  ops?: { initialBehavior?: ScrollBehavior },
): UseScrollInViewReturn => {
  const { initialBehavior = "smooth" } = ops || {};
  const isDisabled = ref(false);

  const behaviour = refAutoReset<ScrollBehavior>(initialBehavior, 500);

  watch(index, () => {
    !isDisabled.value && setScrollPosition();
  });

  const setScrollPosition = (): void => {
    if (index.value === null) return;

    const currentResult = itemList.value[index.value!];

    if (!container.value || !currentResult) return;

    const { offsetTop, clientHeight: resultClientHeight } = currentResult;
    const { clientHeight: ulClientHeight } = container.value;

    scrollTo(offsetTop - ulClientHeight / 2 + resultClientHeight);
  };

  const scrollTo = (top: number): void => {
    container.value?.scrollTo?.({ top, behavior: behaviour.value });
  };

  return { setScrollPosition, behaviour, isDisabled };
};
