import { computed, ref, watch } from "vue";
import { onKeyStroke, refAutoReset } from "@vueuse/core";
import type { Ref } from "vue";
import type { SelectOption } from "../components/select";

export const cleanString = (value: string): string =>
  value
    .toLowerCase()
    .replace(/ /g, "")
    .replace(
      /([\u2700-\u27BF]|[\uE000-\uF8FF]|\uD83C[\uDC00-\uDFFF]|\uD83D[\uDC00-\uDFFF]|[\u2011-\u26FF]|\uD83E[\uDD10-\uDDFF])/g,
      "",
    );

export const useIndexByTyping = <T>({
  isDisabled,
  optionList,
}: {
  optionList: Ref<SelectOption<T>[]>;
  isDisabled?: Ref<boolean | undefined>;
}): {
  index: Ref<number | null>;
  search: Ref<string>;
  isTyping: Ref<boolean>;
} => {
  const index = ref(0);
  const search = refAutoReset("", 1000);

  onKeyStroke(({ keyCode, key }) => {
    if (isDisabled?.value) return;

    const isNumber = keyCode >= 48 && keyCode <= 57;
    const isLetter = keyCode >= 65 && keyCode <= 90;

    if (!(isLetter || isNumber)) return;

    search.value = search.value + key;
  });

  watch([search, optionList], () => {
    if (search.value.length && !isDisabled?.value) {
      const cleanedSearch = cleanString(search.value);
      const newIndex = optionList.value.findIndex(
        ({ label }) =>
          label &&
          cleanString(label).slice(0, cleanedSearch.length) === cleanedSearch,
      );

      if (newIndex >= 0) {
        index.value = newIndex;
      }
    }
  });

  const isTyping = computed(() => Boolean(search.value.length));
  return { index, search, isTyping };
};
