import { type MaybeRef, onMounted, ref, toValue, watch } from "vue";
import type { Ref } from "vue";
import { storeToRefs } from "pinia";
import { useRootStore } from "../stores/root";
import { useCssRgbVar } from "./css-var";
import { useMutationObserver } from "@vueuse/core";

export const useThemeColors = (
  element?: MaybeRef<HTMLElement>,
): {
  fontPrimary: Ref<string>;
  body: Ref<string>;
  base: Ref<string>;
  subdued: Ref<string>;
  note: Ref<string>;
  accent: Ref<string>;
  accentAlt: Ref<string>;
  accentAlt2: Ref<string>;
  success: Ref<string>;
  alt: Ref<string>;
  alt2: Ref<string>;
  alt3: Ref<string>;
  error: Ref<string>;
  warning: Ref<string>;
} => {
  const fontPrimary = ref(useCssRgbVar("--font-primary", element));
  const body = ref(useCssRgbVar("--body", element));
  const base = ref(useCssRgbVar("--base", element));
  const subdued = ref(useCssRgbVar("--subdued", element));
  const note = ref(useCssRgbVar("--note", element));
  const accent = ref(useCssRgbVar("--accent", element));
  const accentAlt = ref(useCssRgbVar("--accent-alt", element));
  const accentAlt2 = ref(useCssRgbVar("--accent-alt2", element));
  const success = ref(useCssRgbVar("--success", element));
  const alt = ref(useCssRgbVar("--alt", element));
  const alt2 = ref(useCssRgbVar("--alt2", element));
  const alt3 = ref(useCssRgbVar("--alt3", element));
  const error = ref(useCssRgbVar("--error", element));
  const warning = ref(useCssRgbVar("--warning", element));
  const rootStore = useRootStore();
  const { normalizedThemeColor } = storeToRefs(rootStore);
  const documentRef = ref();
  const onChange = (): void => {
    fontPrimary.value = useCssRgbVar("--font-primary", element);
    body.value = useCssRgbVar("--body", element);
    base.value = useCssRgbVar("--base", element);
    subdued.value = useCssRgbVar("--subdued", element);
    note.value = useCssRgbVar("--note", element);
    accent.value = useCssRgbVar("--accent", element);
    accentAlt.value = useCssRgbVar("--accent-alt", element);
    accentAlt2.value = useCssRgbVar("--accent-alt2", element);
    success.value = useCssRgbVar("--success", element);
    warning.value = useCssRgbVar("--warning", element);
    error.value = useCssRgbVar("--error", element);
    alt.value = useCssRgbVar("--alt", element);
    alt2.value = useCssRgbVar("--alt2", element);
    alt3.value = useCssRgbVar("--alt3", element);
  };

  useMutationObserver(
    documentRef,
    () => {
      onChange();
    },
    {
      attributes: true,
    },
  );
  watch(
    [normalizedThemeColor, (): HTMLElement | undefined => toValue(element)],
    () => {
      onChange();
    },
    { immediate: true },
  );

  onMounted(() => {
    documentRef.value = document.documentElement;
    onChange();
  });

  return {
    fontPrimary,
    body,
    base,
    subdued,
    note,
    accent,
    accentAlt,
    accentAlt2,
    success,
    alt,
    alt2,
    alt3,
    error,
    warning,
  };
};
